/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_i17lkaD1);
  numBytes += sLine_init(&sLine_yBNMQttX);
  numBytes += sLine_init(&sLine_z8o1tWO5);
  numBytes += sLine_init(&sLine_GylzzhHX);
  numBytes += sLine_init(&sLine_wPCvNx7Z);
  numBytes += sBiquad_init(&sBiquad_s_y3y0JTdX);
  numBytes += sLine_init(&sLine_1e8gzSNb);
  numBytes += sLine_init(&sLine_LzkCL5yO);
  numBytes += sLine_init(&sLine_4ggMVONL);
  numBytes += sLine_init(&sLine_SdJE9qek);
  numBytes += sBiquad_init(&sBiquad_s_LNcCUCDH);
  numBytes += sLine_init(&sLine_PT12fJqN);
  numBytes += sLine_init(&sLine_Vwas8GJG);
  numBytes += sLine_init(&sLine_ARJ4JUFg);
  numBytes += sLine_init(&sLine_Dw8fMamX);
  numBytes += sLine_init(&sLine_XZUHoKAa);
  numBytes += sBiquad_init(&sBiquad_s_ucg4ZGhM);
  numBytes += sLine_init(&sLine_X6SkB0qt);
  numBytes += sLine_init(&sLine_hlEVM56W);
  numBytes += sLine_init(&sLine_dOlal1uc);
  numBytes += sLine_init(&sLine_IV8gRcXT);
  numBytes += sLine_init(&sLine_KlMu4Xnp);
  numBytes += sBiquad_init(&sBiquad_s_G5w08bZA);
  numBytes += sLine_init(&sLine_bMiLZSfL);
  numBytes += sLine_init(&sLine_noGJ8Bs5);
  numBytes += sLine_init(&sLine_y5hvFAve);
  numBytes += sLine_init(&sLine_Z5XQCOKO);
  numBytes += sBiquad_init(&sBiquad_s_jOQwLY2z);
  numBytes += sLine_init(&sLine_LiQwFgQD);
  numBytes += sLine_init(&sLine_42cvQX6S);
  numBytes += sLine_init(&sLine_gmb4aNSK);
  numBytes += sLine_init(&sLine_Mz264Jhf);
  numBytes += sLine_init(&sLine_lMhigCLd);
  numBytes += sBiquad_init(&sBiquad_s_CaCHW6nc);
  numBytes += sLine_init(&sLine_PrtZ0oGD);
  numBytes += sTabread_init(&sTabread_qtYBFBNz, &hTable_4RT7wBYD, true);
  numBytes += sLine_init(&sLine_6vvtxlCT);
  numBytes += sLine_init(&sLine_5AzsYKWF);
  numBytes += sTabread_init(&sTabread_PuHz1jA1, &hTable_53FRlMRA, true);
  numBytes += sLine_init(&sLine_2tYUzbyE);
  numBytes += sRPole_init(&sRPole_A01frPFX);
  numBytes += sDel1_init(&sDel1_KW3cJ0OB);
  numBytes += sTabwrite_init(&sTabwrite_yRd2oXvf, &hTable_4RT7wBYD);
  numBytes += sRPole_init(&sRPole_a82uExel);
  numBytes += sDel1_init(&sDel1_RglmwNh0);
  numBytes += sTabwrite_init(&sTabwrite_LRerAZqE, &hTable_53FRlMRA);
  numBytes += sLine_init(&sLine_9AUnoLtp);
  numBytes += sLine_init(&sLine_Z7ex0L7N);
  numBytes += sRPole_init(&sRPole_RNgupQcF);
  numBytes += sEnv_init(&sEnv_YG5JW3qM, 1024, 512);
  numBytes += sRPole_init(&sRPole_voSv0ICF);
  numBytes += sLine_init(&sLine_xccofcGN);
  numBytes += sLine_init(&sLine_jRTTgQzQ);
  numBytes += sRPole_init(&sRPole_JzDkAFjz);
  numBytes += sEnv_init(&sEnv_SPufftx8, 1024, 512);
  numBytes += sRPole_init(&sRPole_c6jm5OXu);
  numBytes += sLine_init(&sLine_BDpGbARy);
  numBytes += sTabread_init(&sTabread_bDtyNDwy, &hTable_DQ5Vyiir, true);
  numBytes += sLine_init(&sLine_s3wZsadc);
  numBytes += sLine_init(&sLine_SvVixzbw);
  numBytes += sTabread_init(&sTabread_g5HOcDJY, &hTable_QYF8GaNM, true);
  numBytes += sLine_init(&sLine_GeFHToa6);
  numBytes += sRPole_init(&sRPole_KLxU3SqZ);
  numBytes += sDel1_init(&sDel1_Yys5gPNR);
  numBytes += sTabwrite_init(&sTabwrite_oHkOsNvn, &hTable_DQ5Vyiir);
  numBytes += sRPole_init(&sRPole_zNrkbuwV);
  numBytes += sDel1_init(&sDel1_gTL3YliV);
  numBytes += sTabwrite_init(&sTabwrite_PdEEiYqK, &hTable_QYF8GaNM);
  numBytes += sLine_init(&sLine_7hDTQupF);
  numBytes += sLine_init(&sLine_tH7vOrtF);
  numBytes += sRPole_init(&sRPole_bhfHs6AF);
  numBytes += sEnv_init(&sEnv_FqrPj7Xq, 1024, 512);
  numBytes += sRPole_init(&sRPole_sFrhiaDY);
  numBytes += sLine_init(&sLine_i5SdvvvW);
  numBytes += sLine_init(&sLine_cZfhy0zA);
  numBytes += sRPole_init(&sRPole_yuzC8fza);
  numBytes += sEnv_init(&sEnv_IH28Stkf, 1024, 512);
  numBytes += sRPole_init(&sRPole_151Ex3AQ);
  numBytes += sLine_init(&sLine_VBhB9Bpm);
  numBytes += sTabread_init(&sTabread_B8XWFxj1, &hTable_YKt2ghxW, true);
  numBytes += sLine_init(&sLine_22RQL5Ma);
  numBytes += sLine_init(&sLine_FyMxD0mV);
  numBytes += sTabread_init(&sTabread_LWQT8thL, &hTable_jzM1zqD6, true);
  numBytes += sLine_init(&sLine_IEh6AtD0);
  numBytes += sRPole_init(&sRPole_gtYUhcWe);
  numBytes += sDel1_init(&sDel1_YKOxmpuO);
  numBytes += sTabwrite_init(&sTabwrite_aYXx9EZk, &hTable_YKt2ghxW);
  numBytes += sRPole_init(&sRPole_NpCIOON9);
  numBytes += sDel1_init(&sDel1_z5LyoNtB);
  numBytes += sTabwrite_init(&sTabwrite_DhQVDVdp, &hTable_jzM1zqD6);
  numBytes += sLine_init(&sLine_dFOIhILF);
  numBytes += sLine_init(&sLine_LUr5V32B);
  numBytes += sRPole_init(&sRPole_uM50NfZA);
  numBytes += sEnv_init(&sEnv_yWpweweR, 1024, 512);
  numBytes += sRPole_init(&sRPole_H0YxJRMR);
  numBytes += sLine_init(&sLine_0uPTYJCF);
  numBytes += sLine_init(&sLine_taI8BDWv);
  numBytes += sRPole_init(&sRPole_t1BQ1wFm);
  numBytes += sEnv_init(&sEnv_4snyFlJo, 1024, 512);
  numBytes += sRPole_init(&sRPole_JzIvygaC);
  numBytes += cVar_init_f(&cVar_AXbO5Sjv, 0.0f);
  numBytes += cVar_init_f(&cVar_2PytRxQw, 0.0f);
  numBytes += cVar_init_f(&cVar_YdWBrz6Z, 0.0f);
  numBytes += cVar_init_f(&cVar_OY7U2VaK, 0.0f);
  numBytes += cSlice_init(&cSlice_sec0czug, 1, -1);
  numBytes += cVar_init_f(&cVar_r6jI6S3k, 1337.0f);
  numBytes += cVar_init_f(&cVar_BwBNfBwq, 0.0f);
  numBytes += cIf_init(&cIf_uiFkECED, false);
  numBytes += cIf_init(&cIf_jHQzhG6V, false);
  numBytes += cBinop_init(&cBinop_kNr2q6YB, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pqFX5spb, false);
  numBytes += cBinop_init(&cBinop_l4m8mxpF, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JK0T7Dvy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ybJkgaeg, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_JJqnYndt, 0.0f);
  numBytes += cIf_init(&cIf_8pOgANSE, false);
  numBytes += cIf_init(&cIf_pCpcLjBz, false);
  numBytes += cBinop_init(&cBinop_acErh2bt, 0.0f); // __pow
  numBytes += cIf_init(&cIf_luSvNCoN, false);
  numBytes += cBinop_init(&cBinop_2IuDcj7b, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bcyyf44m, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Ms9JZ5yb, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_U3CUCqks, 0.0f);
  numBytes += cIf_init(&cIf_AT06Qcty, false);
  numBytes += cIf_init(&cIf_zctWzWwh, false);
  numBytes += cBinop_init(&cBinop_i7KYXjpx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_CbMxdpY0, false);
  numBytes += cBinop_init(&cBinop_YKjGWZqV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HcV6NCot, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ohikYpkx, -15.0f); // __eq
  numBytes += cIf_init(&cIf_nw1yQZ3V, false);
  numBytes += cSlice_init(&cSlice_U54IMJKl, 1, -1);
  numBytes += cVar_init_f(&cVar_0DrZaClI, 0.0f);
  numBytes += cSlice_init(&cSlice_tVqwU9J3, 1, -1);
  numBytes += cVar_init_f(&cVar_59Eqb6nc, 0.0f);
  numBytes += cSlice_init(&cSlice_DRlNYQ1y, 1, -1);
  numBytes += cVar_init_f(&cVar_RwL9C1j0, 0.0f);
  numBytes += cSlice_init(&cSlice_EcLPIE8y, 1, -1);
  numBytes += cVar_init_f(&cVar_6UOPJPMG, 0.313f);
  numBytes += cBinop_init(&cBinop_LdXrjSLJ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_IyosN1Ee, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bN6ZIlYg, 0.0f);
  numBytes += cVar_init_f(&cVar_7ECkqL6v, 1337.0f);
  numBytes += cVar_init_f(&cVar_qy1magtX, 0.3f);
  numBytes += cBinop_init(&cBinop_0J7q58Ru, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MeaeXQIx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OSnOjlAb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MtXhQyKS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MhD3tWvv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rsfSYylJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LT3umMNb, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_XGxuObTv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_teaIm9gE, 0.0f);
  numBytes += cVar_init_f(&cVar_5g9LEraM, 1337.0f);
  numBytes += cVar_init_f(&cVar_VLwOjnpK, 0.313f);
  numBytes += cBinop_init(&cBinop_KdH993CY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_q3wPmr8Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z917u556, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mMSvHDMv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NJipAxRJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_omFPvZKQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_27PFDhfU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Esq4jNts, 0.0f);
  numBytes += cVar_init_f(&cVar_e0tsPdz0, 1037.0f);
  numBytes += cVar_init_f(&cVar_2CPE1u38, 0.4f);
  numBytes += cBinop_init(&cBinop_L9WyMHci, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XFsdgpON, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4Zg3mOYu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UTXBAWKL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XchRTSu2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JRiEkdYf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0YZk9llM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uL5QktVP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_trkcUVdP, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_wmQRnJgE, 1, -1);
  numBytes += cVar_init_f(&cVar_OQQtW4ZD, 1337.0f);
  numBytes += cVar_init_f(&cVar_c94ZfsFZ, 0.0f);
  numBytes += cIf_init(&cIf_zF5n1D8k, false);
  numBytes += cIf_init(&cIf_B3yFrXIh, false);
  numBytes += cBinop_init(&cBinop_MbFzUv6l, 0.0f); // __pow
  numBytes += cIf_init(&cIf_gDZofhLC, false);
  numBytes += cBinop_init(&cBinop_LcV66Ra3, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_o67b4Exb, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_xcQk46lA, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ZCuWE7OH, 0.0f);
  numBytes += cIf_init(&cIf_cizpixL9, false);
  numBytes += cIf_init(&cIf_az7OyKgD, false);
  numBytes += cBinop_init(&cBinop_12eDnheC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_FQOZIgRD, false);
  numBytes += cBinop_init(&cBinop_pLUfCe0y, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jdJRUDIF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7TBoet2M, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Ngyeh0ac, 0.0f);
  numBytes += cIf_init(&cIf_KHkFZevh, false);
  numBytes += cIf_init(&cIf_q13g6XUs, false);
  numBytes += cBinop_init(&cBinop_xYEcZit8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_lWf3F4vU, false);
  numBytes += cBinop_init(&cBinop_MJNb4GD6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vRRBDsQ2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_iIZwuNaC, -15.0f); // __eq
  numBytes += cIf_init(&cIf_Ll8hwI0n, false);
  numBytes += cSlice_init(&cSlice_ZFlef68p, 1, -1);
  numBytes += cVar_init_f(&cVar_ghHXe96N, 0.0f);
  numBytes += cSlice_init(&cSlice_EGaqDvaW, 1, -1);
  numBytes += cVar_init_f(&cVar_9qUNI9Ma, 0.0f);
  numBytes += cSlice_init(&cSlice_EaaZCNJE, 1, -1);
  numBytes += cVar_init_f(&cVar_S7udzymx, 0.0f);
  numBytes += cSlice_init(&cSlice_60m6jlIx, 1, -1);
  numBytes += cVar_init_f(&cVar_xug79lXV, 0.313f);
  numBytes += cBinop_init(&cBinop_eSOqVG9B, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_t7gnl2eB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_0lo1UXdm, 0.0f);
  numBytes += cVar_init_f(&cVar_nndcYOA8, 1337.0f);
  numBytes += cVar_init_f(&cVar_gKTdoPCl, 0.3f);
  numBytes += cBinop_init(&cBinop_MzeHlptN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QSIAiIx4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vPr4ul7c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DTFOKtQr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9nGNuXyB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ay3bijtw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UMFVd81Q, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ZzFCP7Rk, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7sQbJ5xO, 0.0f);
  numBytes += cVar_init_f(&cVar_KZLXJnN7, 1337.0f);
  numBytes += cVar_init_f(&cVar_1zHzHnpL, 0.313f);
  numBytes += cBinop_init(&cBinop_75zaU9nt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lj73q1A1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4TQ8aOQa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QPHKvK5S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h2fIaCUi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XYvXSc3a, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_1E3UNTBJ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_x0i4aAuz, 0.0f);
  numBytes += cVar_init_f(&cVar_Lkt0X7Xo, 1037.0f);
  numBytes += cVar_init_f(&cVar_cfvC1gyI, 0.4f);
  numBytes += cBinop_init(&cBinop_enfZRpkA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tX41E7KK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3TZKvfNE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Mh9xQZ8R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DHKlj39W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YE8v4wzU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0PiTYQeo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2Pkg2wrO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JmQiuHKg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_mO4Fqcdq, 5705.6f);
  numBytes += cVar_init_f(&cVar_UeJCTzbj, 313.3f);
  numBytes += cBinop_init(&cBinop_eQcYCHlm, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_N7W2h1O7, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_XLfiDkEP, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_KlP72dZE, 0.0f);
  numBytes += cVar_init_f(&cVar_EhBVpuiv, 0.0f);
  numBytes += cVar_init_f(&cVar_G1Z59iCt, 0.0f);
  numBytes += cVar_init_f(&cVar_uSlzpxjw, 0.0f);
  numBytes += cVar_init_f(&cVar_PrQu9CWs, 0.0f);
  numBytes += cVar_init_f(&cVar_TEoo99w7, 0.0f);
  numBytes += cVar_init_f(&cVar_am0fYyba, 0.0f);
  numBytes += cVar_init_f(&cVar_6UfN2APW, 0.0f);
  numBytes += cVar_init_f(&cVar_uBD1aHqX, 0.0f);
  numBytes += cVar_init_f(&cVar_BWZ0T9Lv, 0.0f);
  numBytes += cVar_init_f(&cVar_Ime6shVC, 0.0f);
  numBytes += cVar_init_f(&cVar_e8B7yfFl, 0.0f);
  numBytes += cSlice_init(&cSlice_zEnznjD2, 1, -1);
  numBytes += cVar_init_f(&cVar_aufUVtsL, 0.5f);
  numBytes += cSlice_init(&cSlice_UbZVnYAy, 1, -1);
  numBytes += cVar_init_f(&cVar_i4TRNVX2, 0.2f);
  numBytes += cSlice_init(&cSlice_Es0XesmA, 1, -1);
  numBytes += cVar_init_f(&cVar_X7f4kiAh, 500.0f);
  numBytes += sVarf_init(&sVarf_QBN7SZs6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_clVkHWx3, 600.0f);
  numBytes += cBinop_init(&cBinop_oFL0p0af, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_GPhYARTr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dolqjpk0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_K8IajlmD, 600.0f);
  numBytes += cBinop_init(&cBinop_lUIZ0Mp4, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_WQP5sq2L, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vS3rOOfN, 4000.0f);
  numBytes += cBinop_init(&cBinop_gxF8So82, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DUg41zIx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iHuAaSxG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_971ISvvg, 4000.0f);
  numBytes += cBinop_init(&cBinop_mVQ2gl7F, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CEI8aHd2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Eq1L04zV, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_kxPLMeTv, false);
  numBytes += cBinop_init(&cBinop_EoOtN6HZ, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_CGJF1LFS, 20.0f);
  numBytes += cBinop_init(&cBinop_M8DrB4Px, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Ig0q2iWb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qEpVf039, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TouNETNv, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_VPFGfrx6, false);
  numBytes += cBinop_init(&cBinop_IecUi3Cg, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_bkhmXzJC, 20.0f);
  numBytes += cBinop_init(&cBinop_L060AKfe, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SkutqVR5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6HlDSI4u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QnCJP76l, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ma1HcgvI, 1, -1);
  numBytes += cVar_init_f(&cVar_SxRafSm9, 0.25f);
  numBytes += cDelay_init(this, &cDelay_cgZD5voh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_pNPbDaGT, 0.0f);
  numBytes += hTable_init(&hTable_4RT7wBYD, 256);
  numBytes += cTabhead_init(&cTabhead_mP322oaN, &hTable_4RT7wBYD);
  numBytes += cVar_init_s(&cVar_nDt8bQRO, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_kiCy6LU9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dqtjAmjB, 0.0f);
  numBytes += cBinop_init(&cBinop_dFERwm9d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H4apkJBN, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_izB1rLCR, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_tB8Qn3gC, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_k57PynYu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wrS9M75r, 0.0f);
  numBytes += hTable_init(&hTable_53FRlMRA, 256);
  numBytes += cTabhead_init(&cTabhead_M1GclX0t, &hTable_53FRlMRA);
  numBytes += cVar_init_s(&cVar_8sOvARzH, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_GJ6vOKdX, 0.0f);
  numBytes += cDelay_init(this, &cDelay_af3DA8PY, 0.0f);
  numBytes += cBinop_init(&cBinop_qLZrWkYL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Li808Xeh, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_gYQ0TuuK, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_EVQDimhW, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_3VUtJlMC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UaM1xjog, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e5CwZl64, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eqXmRtHi, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_R1R0odHB, 1, -1);
  numBytes += cVar_init_f(&cVar_Y5N5TASe, 0.5f);
  numBytes += cSlice_init(&cSlice_2110VYRw, 1, -1);
  numBytes += cVar_init_f(&cVar_kaDhFWoC, 0.2f);
  numBytes += cSlice_init(&cSlice_m9QLaDg1, 1, -1);
  numBytes += cVar_init_f(&cVar_pcuyoBHd, 500.0f);
  numBytes += sVarf_init(&sVarf_ehM1n0Tj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7OwCZxc4, 600.0f);
  numBytes += cBinop_init(&cBinop_cRENwh3u, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_VME72CB5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RIgLIP4l, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_29y5FrVr, 600.0f);
  numBytes += cBinop_init(&cBinop_jtKCDY0e, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_w3oxMSC7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jHr3jXLF, 4000.0f);
  numBytes += cBinop_init(&cBinop_R49cN8nF, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Edfj2HRe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C1IBS9qV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_CXvek7WL, 4000.0f);
  numBytes += cBinop_init(&cBinop_RpKWGveH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8i7I6oih, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xy0pJ8Km, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_dRwS10lm, false);
  numBytes += cBinop_init(&cBinop_4cZCLcsy, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_JJS60vaC, 20.0f);
  numBytes += cBinop_init(&cBinop_MaEMOu7t, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_OQkyyzXS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_D3kKcMEt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VYEmcgEk, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_sqNY7CWn, false);
  numBytes += cBinop_init(&cBinop_HkaNB7eW, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_QYAZVMtJ, 20.0f);
  numBytes += cBinop_init(&cBinop_9O0eZbhB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_p9ZiHA4h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aMD6959m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c4bbhSlr, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_XaVp0IRR, 1, -1);
  numBytes += cVar_init_f(&cVar_KQ35b6SB, 0.25f);
  numBytes += cDelay_init(this, &cDelay_DCAHKnuS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_0WapkC5U, 0.0f);
  numBytes += hTable_init(&hTable_DQ5Vyiir, 256);
  numBytes += cTabhead_init(&cTabhead_nTffNHYv, &hTable_DQ5Vyiir);
  numBytes += cVar_init_s(&cVar_8R1r3GfX, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_pU3CSZ1H, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tSWT7EAo, 0.0f);
  numBytes += cBinop_init(&cBinop_uRnFoNJd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_htUCZ4zF, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_uV9q2HKe, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_OnGPKqzk, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Xxxv7RGj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_uDLiULvN, 0.0f);
  numBytes += hTable_init(&hTable_QYF8GaNM, 256);
  numBytes += cTabhead_init(&cTabhead_Ghe7FRaA, &hTable_QYF8GaNM);
  numBytes += cVar_init_s(&cVar_MyF71C90, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_NgjKR9B5, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ANA7hJG8, 0.0f);
  numBytes += cBinop_init(&cBinop_pZnVhTXy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8r1fured, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Hyf6V3tW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_YzD2q73D, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_aUF6JAUX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2wHf2d71, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ygsu9OUN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qT50L60W, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_U9s6J2ag, 1, -1);
  numBytes += cVar_init_f(&cVar_X13MR2Rt, 0.5f);
  numBytes += cSlice_init(&cSlice_NBxUF6Vj, 1, -1);
  numBytes += cVar_init_f(&cVar_jAWVpFLO, 0.2f);
  numBytes += cSlice_init(&cSlice_NIvpV3Kc, 1, -1);
  numBytes += cVar_init_f(&cVar_QFuhcyby, 500.0f);
  numBytes += sVarf_init(&sVarf_55TTeHmd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MqAiXUAP, 600.0f);
  numBytes += cBinop_init(&cBinop_2GAB42dT, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_H9kF90De, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e3FpJZQ8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_BDs7NsPI, 600.0f);
  numBytes += cBinop_init(&cBinop_7fyfHX5p, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_H7IJF0p8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PufZaAAw, 4000.0f);
  numBytes += cBinop_init(&cBinop_t3YPnRSw, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_b7cQaKsN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iRxYRSYl, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_uq11AUSS, 4000.0f);
  numBytes += cBinop_init(&cBinop_8XXVvpyC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5rkpezbR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j0tWJvbN, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_8GfQdgfH, false);
  numBytes += cBinop_init(&cBinop_axXbv7RJ, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_fllZJJZW, 20.0f);
  numBytes += cBinop_init(&cBinop_QVackeBE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bnEfwBc5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CKBnMWEE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X37SBS4D, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_awXaDY6t, false);
  numBytes += cBinop_init(&cBinop_6cJsioaY, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_bIc6VeQS, 20.0f);
  numBytes += cBinop_init(&cBinop_Bqx4eDho, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_AlWM4wZy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1BmDoouT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CCiOsY7B, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_TpZj30Zv, 1, -1);
  numBytes += cVar_init_f(&cVar_3VEIbLft, 0.25f);
  numBytes += cDelay_init(this, &cDelay_t4x0nW3q, 0.0f);
  numBytes += cDelay_init(this, &cDelay_u4QrhoXP, 0.0f);
  numBytes += hTable_init(&hTable_YKt2ghxW, 256);
  numBytes += cTabhead_init(&cTabhead_GvFFjUM4, &hTable_YKt2ghxW);
  numBytes += cVar_init_s(&cVar_YcXXOJls, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_TF3bQk8l, 0.0f);
  numBytes += cDelay_init(this, &cDelay_htO5S82y, 0.0f);
  numBytes += cBinop_init(&cBinop_0Lndy6LB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q2gSv8Ub, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_etns9R6w, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_b8sDN3zB, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_aIsfMUNh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_a2m3hGAn, 0.0f);
  numBytes += hTable_init(&hTable_jzM1zqD6, 256);
  numBytes += cTabhead_init(&cTabhead_b2J7anHR, &hTable_jzM1zqD6);
  numBytes += cVar_init_s(&cVar_qFRlg7nZ, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_whGtNGtH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_1nsFx5nZ, 0.0f);
  numBytes += cBinop_init(&cBinop_WjUWGB29, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eybfTXrz, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_5U974t19, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_DkmvqNnL, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_oIVygBWk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o10vBUDk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xywW3tYe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7rpfwOsr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6i2C70nA, 1.0f);
  numBytes += cIf_init(&cIf_BVai2vmG, false);
  numBytes += cIf_init(&cIf_T2QeuIQf, false);
  numBytes += cVar_init_f(&cVar_uNSVRbnI, 0.0f);
  numBytes += cVar_init_f(&cVar_G9xelZZI, 0.0f);
  numBytes += cVar_init_f(&cVar_J2BMUtBu, 1.0f);
  numBytes += cIf_init(&cIf_xk82lyPZ, false);
  numBytes += cIf_init(&cIf_F0S9j6Og, false);
  numBytes += cVar_init_f(&cVar_MUjWEBqk, 0.0f);
  numBytes += cVar_init_f(&cVar_bExVQ0z9, 0.0f);
  numBytes += cVar_init_f(&cVar_8Oae9Ald, 1.0f);
  numBytes += cIf_init(&cIf_hoo4U0Yq, false);
  numBytes += cIf_init(&cIf_YJVqRtQQ, false);
  numBytes += cVar_init_f(&cVar_XuHGbgAp, 0.0f);
  numBytes += cVar_init_f(&cVar_iKjIJTl7, 0.0f);
  numBytes += cVar_init_f(&cVar_BmF2IkXI, 60000.0f);
  numBytes += cVar_init_f(&cVar_swIxS9aR, 500.0f);
  numBytes += cSlice_init(&cSlice_vCobGPtf, 1, -1);
  numBytes += cSlice_init(&cSlice_BOqdh718, 1, -1);
  numBytes += cVar_init_f(&cVar_wvYnfM35, 0.0f);
  numBytes += cIf_init(&cIf_l5hExdQx, false);
  numBytes += cBinop_init(&cBinop_8oc4HfsZ, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_2yMkZmvh, 120.0f);
  numBytes += cBinop_init(&cBinop_WA72jibW, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_FW70wCPc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_RTzZpKrY, 60000.0f);
  numBytes += cVar_init_f(&cVar_auJ67urk, 500.0f);
  numBytes += cSlice_init(&cSlice_rfDyMAmi, 1, -1);
  numBytes += cSlice_init(&cSlice_E9Gg8hmi, 1, -1);
  numBytes += cVar_init_f(&cVar_XLX15DF5, 0.0f);
  numBytes += cIf_init(&cIf_tSWQ83Id, false);
  numBytes += cBinop_init(&cBinop_tdnfQ1vn, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_sPzEKHQg, 120.0f);
  numBytes += cBinop_init(&cBinop_8Z4rVE7W, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_S1eT8FbP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_adciQ7bB, 60000.0f);
  numBytes += cVar_init_f(&cVar_j11lXJy0, 500.0f);
  numBytes += cSlice_init(&cSlice_ISNfMnob, 1, -1);
  numBytes += cSlice_init(&cSlice_EzuJKYnl, 1, -1);
  numBytes += cVar_init_f(&cVar_NECCct7V, 0.0f);
  numBytes += cIf_init(&cIf_7GS2bNQo, false);
  numBytes += cBinop_init(&cBinop_t2XOh69n, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_1oPkpXdG, 120.0f);
  numBytes += cBinop_init(&cBinop_NiRu6Iid, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_5jP09w83, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_eKzojl3k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r3tDfpdC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7qMpAmUj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FlKTU6zS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_346UYbiu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Nl6aQvIT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J2BGifcF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TtZXnZxH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RN5jPWxZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AEmVFssH, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_YG5JW3qM);
  sEnv_free(&sEnv_SPufftx8);
  sEnv_free(&sEnv_FqrPj7Xq);
  sEnv_free(&sEnv_IH28Stkf);
  sEnv_free(&sEnv_yWpweweR);
  sEnv_free(&sEnv_4snyFlJo);
  hTable_free(&hTable_4RT7wBYD);
  hTable_free(&hTable_53FRlMRA);
  hTable_free(&hTable_DQ5Vyiir);
  hTable_free(&hTable_QYF8GaNM);
  hTable_free(&hTable_YKt2ghxW);
  hTable_free(&hTable_jzM1zqD6);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_4RT7wBYD; // del-1349-delayL
    case 0x19A00729: return &hTable_53FRlMRA; // del-1349-delayR
    case 0x584C8281: return &hTable_DQ5Vyiir; // del-1428-delayL
    case 0x54BF59F6: return &hTable_QYF8GaNM; // del-1428-delayR
    case 0xBCE693A: return &hTable_YKt2ghxW; // del-1507-delayL
    case 0x95A380B3: return &hTable_jzM1zqD6; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5yCl8fDU_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IC2TnVhV_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_plToDt7D_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1B1Gbih0_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jVfIidcO_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mIvg7UN0_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sayeqbw0_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wgS0X0Li_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1cXn7H0j_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2l0BSAkp_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IVOJq5So_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cUBaNGsM_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GKg9dXJw_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yn9OZvuM_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jThceXdv_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RJK0hIlK_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RcHHnESz_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ov4mLnwK_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vZ7cjAHH_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5z397qdj_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SfhctQtB_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RVeaHMk0_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lm4GTJbr_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pKjAgZQ3_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RZYknDTb_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ultMTieE_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8qkhXCOE_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4tNRFDSa_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uBv0Jhs8_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uVvFYnz7_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IPq9UB7V_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h8ULmtvk_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VzCIyYuw_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GNyMy371_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HZ4TsLTq_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2aJUMg2c_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ABQH6Iz8_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_13WWtu6B_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Got0Xith_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_axOAg1yy_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UaNNQi3m_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_02qdIdsm_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vdYXKS9n_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KhFyb1nq_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DFBQ1Y86_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jR89ybvC_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8B3hjd2I_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_owScGmPZ_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zULV5ztl_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wBqOnhFn_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rl2FVR1I_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RuSxj0LV_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R7RAs2Im_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1syAALUa_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xNlGnxRW_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5LcZgoEx_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8A9rf8Sw_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NBIhRw3L_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VynHoDs6_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bOtZ65lP_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bf1i9WFZ_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DAsxlMQV_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MUKQ7iY6_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_91hXEloU_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_AXbO5Sjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EPmQ47fi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2PytRxQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YcbDREd3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YdWBrz6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4gJZ9QBM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_OY7U2VaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8sCLLZDg_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jz4HeBxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_65Yiq8hX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3NTEMuyW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_lzBiLll8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sec0czug, 0, m, &cSlice_sec0czug_sendMessage);
      break;
    }
    default: {
      cSwitchcase_d76vc4QF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_sec0czug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V2LzCY9I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V2LzCY9I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_r6jI6S3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V2LzCY9I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_V2LzCY9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RZYknDTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BwBNfBwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mIw1Z5ok_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_uiFkECED, 0, m, &cIf_uiFkECED_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_uiFkECED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VCHoCh8c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_jHQzhG6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_o9kUZiAf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_IguN79Fe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_oggQXAqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kNr2q6YB, HV_BINOP_POW, 0, m, &cBinop_kNr2q6YB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kNr2q6YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pqFX5spb, 0, m, &cIf_pqFX5spb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b0Ni29Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GWhCBfui_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xugpFKSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHQzhG6V, 0, m, &cIf_jHQzhG6V_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_I7u0Iw65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4UM93eif_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4UM93eif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHQzhG6V, 1, m, &cIf_jHQzhG6V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IguN79Fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_b0Ni29Zr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_o9kUZiAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pqFX5spb, 0, m, &cIf_pqFX5spb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GWhCBfui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kNr2q6YB, HV_BINOP_POW, 1, m, &cBinop_kNr2q6YB_sendMessage);
  cMsg_oggQXAqP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_pqFX5spb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_0YZk9llM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mIw1Z5ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uiFkECED, 1, m, &cIf_uiFkECED_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VCHoCh8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JK0T7Dvy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JK0T7Dvy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybJkgaeg, HV_BINOP_EQ, 1, m, &cBinop_ybJkgaeg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Sn6ymzff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_l4m8mxpF, HV_BINOP_ADD, 0, m, &cBinop_l4m8mxpF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l4m8mxpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I7u0Iw65_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xugpFKSK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JK0T7Dvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pqFX5spb, 1, m, &cIf_pqFX5spb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ybJkgaeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BdSq1Ivu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_BdSq1Ivu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0YZk9llM, m);
}

void Heavy_WSTD_DL3Y::cCast_trW4PTkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l4m8mxpF, HV_BINOP_ADD, 1, m, &cBinop_l4m8mxpF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JK0T7Dvy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JK0T7Dvy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybJkgaeg, HV_BINOP_EQ, 0, m, &cBinop_ybJkgaeg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7aYqXK2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BwBNfBwq, 0, m, &cVar_BwBNfBwq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ThGChaRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sn6ymzff_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JJqnYndt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mXkK1KmZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_8pOgANSE, 0, m, &cIf_8pOgANSE_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_8pOgANSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cj0UTBMC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_pCpcLjBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LtJeUq1v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uZyAFYzl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_XaOvNV4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_acErh2bt, HV_BINOP_POW, 0, m, &cBinop_acErh2bt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_acErh2bt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_luSvNCoN, 0, m, &cIf_luSvNCoN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0WwEoDob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_llMubjDU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iX5xPjEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pCpcLjBz, 0, m, &cIf_pCpcLjBz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LYva1XqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sUsCrkdM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sUsCrkdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pCpcLjBz, 1, m, &cIf_pCpcLjBz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uZyAFYzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_0WwEoDob_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LtJeUq1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_luSvNCoN, 0, m, &cIf_luSvNCoN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_llMubjDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_acErh2bt, HV_BINOP_POW, 1, m, &cBinop_acErh2bt_sendMessage);
  cMsg_XaOvNV4E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_luSvNCoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QsMcia39_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VHotDZ3V_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_HBLkFG4e_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mXkK1KmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8pOgANSE, 1, m, &cIf_8pOgANSE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cj0UTBMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bcyyf44m, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bcyyf44m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ms9JZ5yb, HV_BINOP_EQ, 1, m, &cBinop_Ms9JZ5yb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7tvIhdFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2IuDcj7b, HV_BINOP_ADD, 0, m, &cBinop_2IuDcj7b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2IuDcj7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LYva1XqP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iX5xPjEz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bcyyf44m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_luSvNCoN, 1, m, &cIf_luSvNCoN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ms9JZ5yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_azPUUqIt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_azPUUqIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QsMcia39_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VHotDZ3V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_HBLkFG4e_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AKyjT22I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2IuDcj7b, HV_BINOP_ADD, 1, m, &cBinop_2IuDcj7b_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bcyyf44m, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bcyyf44m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ms9JZ5yb, HV_BINOP_EQ, 0, m, &cBinop_Ms9JZ5yb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SlZ1ehiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JJqnYndt, 0, m, &cVar_JJqnYndt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gPs1ImaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7tvIhdFq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_U3CUCqks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ux3SQPNG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_AT06Qcty, 0, m, &cIf_AT06Qcty_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_AT06Qcty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tkvBIkxb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_zctWzWwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_31WICGJ1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XdsOEebK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_cAIZ8F37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_i7KYXjpx, HV_BINOP_POW, 0, m, &cBinop_i7KYXjpx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i7KYXjpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CbMxdpY0, 0, m, &cIf_CbMxdpY0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7rDyKVRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ek21DTF8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_V2JW2ER5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zctWzWwh, 0, m, &cIf_zctWzWwh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sQwQ0Tp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F3jQczDr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F3jQczDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zctWzWwh, 1, m, &cIf_zctWzWwh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XdsOEebK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_7rDyKVRM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_31WICGJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CbMxdpY0, 0, m, &cIf_CbMxdpY0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ek21DTF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i7KYXjpx, HV_BINOP_POW, 1, m, &cBinop_i7KYXjpx_sendMessage);
  cMsg_cAIZ8F37_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_CbMxdpY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_trkcUVdP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_ux3SQPNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AT06Qcty, 1, m, &cIf_AT06Qcty_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tkvBIkxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcV6NCot, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HcV6NCot_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ohikYpkx, HV_BINOP_EQ, 1, m, &cBinop_ohikYpkx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mZYR9DvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YKjGWZqV, HV_BINOP_ADD, 0, m, &cBinop_YKjGWZqV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YKjGWZqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sQwQ0Tp1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V2JW2ER5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HcV6NCot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CbMxdpY0, 1, m, &cIf_CbMxdpY0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ohikYpkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XV4zMch1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_XV4zMch1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_trkcUVdP, m);
}

void Heavy_WSTD_DL3Y::cCast_cJACEb9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YKjGWZqV, HV_BINOP_ADD, 1, m, &cBinop_YKjGWZqV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcV6NCot, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HcV6NCot_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ohikYpkx, HV_BINOP_EQ, 0, m, &cBinop_ohikYpkx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WtsWSQAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U3CUCqks, 0, m, &cVar_U3CUCqks_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DAXq6YLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mZYR9DvK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_nw1yQZ3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_uL5QktVP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_t2IQTM9z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U54IMJKl, 0, m, &cSlice_U54IMJKl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kyMZCqSH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_U54IMJKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_huXCg1k0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_huXCg1k0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_0DrZaClI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_huXCg1k0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_huXCg1k0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lm4GTJbr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_kyMZCqSH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tVqwU9J3, 0, m, &cSlice_tVqwU9J3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lzBiLll8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_tVqwU9J3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_S6vpV069_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_S6vpV069_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_59Eqb6nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S6vpV069_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_S6vpV069_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8qkhXCOE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_d76vc4QF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DRlNYQ1y, 0, m, &cSlice_DRlNYQ1y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hzRfw6G9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_DRlNYQ1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SkciGlSh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SkciGlSh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RwL9C1j0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SkciGlSh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SkciGlSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pKjAgZQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hzRfw6G9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EcLPIE8y, 0, m, &cSlice_EcLPIE8y_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_EcLPIE8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hlNrywUz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hlNrywUz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_6UOPJPMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hlNrywUz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_hlNrywUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ultMTieE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7Iq7Awh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i17lkaD1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DDoXU75I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yBNMQttX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vzCP7BQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z8o1tWO5, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gdsyFYa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GylzzhHX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Zt2i22dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wPCvNx7Z, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vf9DtBpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6Xworoto_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6Xworoto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LdXrjSLJ, HV_BINOP_DIVIDE, 1, m, &cBinop_LdXrjSLJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ni99mdR_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_eayY0SXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_pVhJ19i4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rEJpBr1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eayY0SXR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pVhJ19i4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LdXrjSLJ, HV_BINOP_DIVIDE, 0, m, &cBinop_LdXrjSLJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8ni99mdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rEJpBr1W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LdXrjSLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IyosN1Ee, HV_BINOP_MULTIPLY, 1, m, &cBinop_IyosN1Ee_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IyosN1Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sUJRyxYb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gSx2icmr_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_0u4o7Az0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iCTVb7Sd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_AcNLStY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oJS0PixS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UcMCHpGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HPm0BNOb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HPm0BNOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IyosN1Ee, HV_BINOP_MULTIPLY, 0, m, &cBinop_IyosN1Ee_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I56wzIen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_gNtaUAH0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gNtaUAH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xyntstEz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hJxNltKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bN6ZIlYg, 1, m, &cVar_bN6ZIlYg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bN6ZIlYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5oawurvH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FW1h5i3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeaeXQIx, HV_BINOP_MULTIPLY, 1, m, &cBinop_MeaeXQIx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x1OJoXzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FW1h5i3P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NnhKPyck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1OyQ20rc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1OyQ20rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OSnOjlAb, HV_BINOP_MULTIPLY, 1, m, &cBinop_OSnOjlAb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RHVJqtUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MtXhQyKS, HV_BINOP_MULTIPLY, 1, m, &cBinop_MtXhQyKS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5NR4l5kK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RHVJqtUr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8crXyorU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MhD3tWvv, HV_BINOP_MULTIPLY, 1, m, &cBinop_MhD3tWvv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XLw2SBSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dbC57o6U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dbC57o6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rsfSYylJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_rsfSYylJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7ECkqL6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_viuBBOCG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UcMCHpGH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WUuYgOpl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_qy1magtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_I56wzIen_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sUJRyxYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0u4o7Az0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gSx2icmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_AcNLStY5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_iCTVb7Sd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uVvFYnz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_oJS0PixS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uBv0Jhs8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_t8lUO4hJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4tNRFDSa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xyntstEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1CzSylOO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1CzSylOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0J7q58Ru, HV_BINOP_MULTIPLY, 1, m, &cBinop_0J7q58Ru_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0J7q58Ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7xTpzhGJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7xTpzhGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t8lUO4hJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5oawurvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4hTUlFX5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4hTUlFX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DXIM1Hea_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N9ANUJt4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3qfeBpra_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iqBoZjck_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qTFi8YTe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ElKx0TZx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MeaeXQIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Iq7Awh9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OSnOjlAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DDoXU75I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MtXhQyKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vzCP7BQ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MhD3tWvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gdsyFYa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rsfSYylJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zt2i22dr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vSRiKQYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ECkqL6v, 0, m, &cVar_7ECkqL6v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_P5KysfNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qy1magtX, 1, m, &cVar_qy1magtX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iqBoZjck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MtXhQyKS, HV_BINOP_MULTIPLY, 0, m, &cBinop_MtXhQyKS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DXIM1Hea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_ElKx0TZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeaeXQIx, HV_BINOP_MULTIPLY, 0, m, &cBinop_MeaeXQIx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3qfeBpra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MhD3tWvv, HV_BINOP_MULTIPLY, 0, m, &cBinop_MhD3tWvv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qTFi8YTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OSnOjlAb, HV_BINOP_MULTIPLY, 0, m, &cBinop_OSnOjlAb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N9ANUJt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rsfSYylJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_rsfSYylJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WUuYgOpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bN6ZIlYg, 0, m, &cVar_bN6ZIlYg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_viuBBOCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qy1magtX, 0, m, &cVar_qy1magtX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QuAEa2t4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1e8gzSNb, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_s0DQdRZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LzkCL5yO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dY3fSBlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4ggMVONL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CpFBSNnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SdJE9qek, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Rue6gK9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jFPqWG5p_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_jFPqWG5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LT3umMNb, HV_BINOP_DIVIDE, 1, m, &cBinop_LT3umMNb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2bjN0xpz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_PAYapGuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JQhov2H2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZpGYI9gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_PAYapGuB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JQhov2H2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LT3umMNb, HV_BINOP_DIVIDE, 0, m, &cBinop_LT3umMNb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2bjN0xpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZpGYI9gv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LT3umMNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XGxuObTv, HV_BINOP_MULTIPLY, 1, m, &cBinop_XGxuObTv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XGxuObTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sJk6dG69_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l24264O3_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_leeQwjE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_H42bLeWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_X3VCzwDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OmMzuYDI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dAxK7hHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ILHctuI4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ILHctuI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XGxuObTv, HV_BINOP_MULTIPLY, 0, m, &cBinop_XGxuObTv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n3caimfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Lo9Zpfno_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lo9Zpfno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DXZDUkIQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rH5KhOhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z917u556, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z917u556_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ao4oJ0j8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_teaIm9gE, 1, m, &cVar_teaIm9gE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cFV3Qaul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mMSvHDMv, HV_BINOP_MULTIPLY, 1, m, &cBinop_mMSvHDMv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZKfDDCZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_k7YuUcju_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k7YuUcju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NJipAxRJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_NJipAxRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_teaIm9gE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BTngiO9G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_5g9LEraM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7TMgpqkK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_dAxK7hHu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E3jWxo6z_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VLwOjnpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_n3caimfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l24264O3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_X3VCzwDY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sJk6dG69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_leeQwjE9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_H42bLeWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VzCIyYuw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_OmMzuYDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_h8ULmtvk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BoJ5NMc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IPq9UB7V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_DXZDUkIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3yOT297s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3yOT297s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KdH993CY, HV_BINOP_MULTIPLY, 1, m, &cBinop_KdH993CY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KdH993CY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jwUwWBCl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jwUwWBCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BoJ5NMc5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_BTngiO9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HezVY96s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HezVY96s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lpnx7kTD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uAbdtnXx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BuMG2Ikv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LZCjzdOH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q3wPmr8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QuAEa2t4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Z917u556_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s0DQdRZc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mMSvHDMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dY3fSBlY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NJipAxRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CpFBSNnG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QHYt7uXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VLwOjnpK, 1, m, &cVar_VLwOjnpK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kl9iALGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5g9LEraM, 0, m, &cVar_5g9LEraM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7TMgpqkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VLwOjnpK, 0, m, &cVar_VLwOjnpK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_E3jWxo6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_teaIm9gE, 0, m, &cVar_teaIm9gE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uAbdtnXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mMSvHDMv, HV_BINOP_MULTIPLY, 0, m, &cBinop_mMSvHDMv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LZCjzdOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q3wPmr8Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_q3wPmr8Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lpnx7kTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NJipAxRJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_NJipAxRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BuMG2Ikv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z917u556, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z917u556_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HgW2E4wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PT12fJqN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_johZOHhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vwas8GJG, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1mBc04Uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ARJ4JUFg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_BqNKxyXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dw8fMamX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nyt9u0ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XZUHoKAa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GE8e1FmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uexQY21A_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uexQY21A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_omFPvZKQ, HV_BINOP_DIVIDE, 1, m, &cBinop_omFPvZKQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VE5uf5Bz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_mRdrFCIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_1Axp3WBO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_63a1LrPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_mRdrFCIk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1Axp3WBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_omFPvZKQ, HV_BINOP_DIVIDE, 0, m, &cBinop_omFPvZKQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VE5uf5Bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_63a1LrPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_omFPvZKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_27PFDhfU, HV_BINOP_MULTIPLY, 1, m, &cBinop_27PFDhfU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_27PFDhfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tODw8SUR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LHgapLrn_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ReZMPDFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bBnsCyyC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_YfM8Kvi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bJLp3C5V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ub11UVWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_DFAgcVJR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DFAgcVJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_27PFDhfU, HV_BINOP_MULTIPLY, 0, m, &cBinop_27PFDhfU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_APgC9a7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_86ia0vfc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_86ia0vfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bP0MET5c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VtKqlvTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XFsdgpON, HV_BINOP_MULTIPLY, 1, m, &cBinop_XFsdgpON_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XmpgrtlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oHY9EMc1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oHY9EMc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VtKqlvTt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LsiIBKYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vGAkBqwp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vGAkBqwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Zg3mOYu, HV_BINOP_MULTIPLY, 1, m, &cBinop_4Zg3mOYu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cUKIdsBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UTXBAWKL, HV_BINOP_MULTIPLY, 1, m, &cBinop_UTXBAWKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_B2HU7HQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PRkK3nGD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PRkK3nGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cUKIdsBU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IfViw6E7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Esq4jNts, 1, m, &cVar_Esq4jNts_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HLnds4WB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XchRTSu2, HV_BINOP_MULTIPLY, 1, m, &cBinop_XchRTSu2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pRJ1AnHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7SGcBfuA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7SGcBfuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRiEkdYf, HV_BINOP_MULTIPLY, 1, m, &cBinop_JRiEkdYf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Esq4jNts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FXQsMX6I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_e0tsPdz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w7UfYh3p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Ub11UVWp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8khhYvLN_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2CPE1u38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_APgC9a7e_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LHgapLrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_YfM8Kvi0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tODw8SUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ReZMPDFC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_bBnsCyyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2aJUMg2c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_bJLp3C5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HZ4TsLTq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_54j7T0zu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GNyMy371_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_bP0MET5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PCZ1b6v0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PCZ1b6v0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9WyMHci, HV_BINOP_MULTIPLY, 1, m, &cBinop_L9WyMHci_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L9WyMHci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7TocBw3s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7TocBw3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_54j7T0zu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_FXQsMX6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LTwz168u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LTwz168u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sr7Lm7Qj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DmEZlZbe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EMb9DHC8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tHm3TXhL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H0wnwzmk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gfqpce8I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XFsdgpON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HgW2E4wd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4Zg3mOYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_johZOHhA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UTXBAWKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1mBc04Uy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XchRTSu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BqNKxyXA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JRiEkdYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nyt9u0ib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_SjiN1iXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e0tsPdz0, 0, m, &cVar_e0tsPdz0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jE8aAAAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2CPE1u38, 1, m, &cVar_2CPE1u38_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tHm3TXhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UTXBAWKL, HV_BINOP_MULTIPLY, 0, m, &cBinop_UTXBAWKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Sr7Lm7Qj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_Gfqpce8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XFsdgpON, HV_BINOP_MULTIPLY, 0, m, &cBinop_XFsdgpON_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EMb9DHC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XchRTSu2, HV_BINOP_MULTIPLY, 0, m, &cBinop_XchRTSu2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H0wnwzmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Zg3mOYu, HV_BINOP_MULTIPLY, 0, m, &cBinop_4Zg3mOYu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DmEZlZbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRiEkdYf, HV_BINOP_MULTIPLY, 0, m, &cBinop_JRiEkdYf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8khhYvLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Esq4jNts, 0, m, &cVar_Esq4jNts_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_w7UfYh3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2CPE1u38, 0, m, &cVar_2CPE1u38_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QsMcia39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nw1yQZ3V, 1, m, &cIf_nw1yQZ3V_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m159qOBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uL5QktVP, m);
}

void Heavy_WSTD_DL3Y::cBinop_VHotDZ3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m159qOBa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HBLkFG4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nw1yQZ3V, 0, m, &cIf_nw1yQZ3V_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ibKFf8PH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wmQRnJgE, 0, m, &cSlice_wmQRnJgE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KDYhzccP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_wmQRnJgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UeE5khYa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UeE5khYa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_OQQtW4ZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UeE5khYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_UeE5khYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Got0Xith_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_c94ZfsFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DFpd2IwB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_zF5n1D8k, 0, m, &cIf_zF5n1D8k_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_zF5n1D8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WoLkU0lP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_B3yFrXIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_H7haSp9u_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_u3tgA84E_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Z4kx68bE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MbFzUv6l, HV_BINOP_POW, 0, m, &cBinop_MbFzUv6l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MbFzUv6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gDZofhLC, 0, m, &cIf_gDZofhLC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9NfgDBYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_rV27kO3t_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_se4NZ9cA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0vWgfNUx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iSyMzMW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B3yFrXIh, 0, m, &cIf_B3yFrXIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0vWgfNUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B3yFrXIh, 1, m, &cIf_B3yFrXIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u3tgA84E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_9NfgDBYj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_H7haSp9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gDZofhLC, 0, m, &cIf_gDZofhLC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rV27kO3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MbFzUv6l, HV_BINOP_POW, 1, m, &cBinop_MbFzUv6l_sendMessage);
  cMsg_Z4kx68bE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_gDZofhLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_0PiTYQeo, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_DFpd2IwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zF5n1D8k, 1, m, &cIf_zF5n1D8k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WoLkU0lP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o67b4Exb, HV_BINOP_GREATER_THAN, 1, m, &cBinop_o67b4Exb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xcQk46lA, HV_BINOP_EQ, 1, m, &cBinop_xcQk46lA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AUsC3Zv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LcV66Ra3, HV_BINOP_ADD, 0, m, &cBinop_LcV66Ra3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LcV66Ra3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_se4NZ9cA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iSyMzMW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o67b4Exb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gDZofhLC, 1, m, &cIf_gDZofhLC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xcQk46lA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7VcmF6cL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7VcmF6cL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0PiTYQeo, m);
}

void Heavy_WSTD_DL3Y::cCast_BBNKACd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c94ZfsFZ, 0, m, &cVar_c94ZfsFZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1N3t94x0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AUsC3Zv3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_quJWkzXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LcV66Ra3, HV_BINOP_ADD, 1, m, &cBinop_LcV66Ra3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o67b4Exb, HV_BINOP_GREATER_THAN, 0, m, &cBinop_o67b4Exb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xcQk46lA, HV_BINOP_EQ, 0, m, &cBinop_xcQk46lA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZCuWE7OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IQTr8And_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cizpixL9, 0, m, &cIf_cizpixL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_cizpixL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XeAAg8NX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_az7OyKgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QXChKrhi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_SPKVYLis_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_qD0ISvOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_12eDnheC, HV_BINOP_POW, 0, m, &cBinop_12eDnheC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_12eDnheC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FQOZIgRD, 0, m, &cIf_FQOZIgRD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hARJ5G1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_zS4ocibB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YmC01PcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JuuyNEJp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EdQSB3B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_az7OyKgD, 0, m, &cIf_az7OyKgD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JuuyNEJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_az7OyKgD, 1, m, &cIf_az7OyKgD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SPKVYLis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hARJ5G1l_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QXChKrhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FQOZIgRD, 0, m, &cIf_FQOZIgRD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zS4ocibB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_12eDnheC, HV_BINOP_POW, 1, m, &cBinop_12eDnheC_sendMessage);
  cMsg_qD0ISvOe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_FQOZIgRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P5y0MbnT_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kgsba2hL_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_GmIg8bWN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_IQTr8And_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cizpixL9, 1, m, &cIf_cizpixL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XeAAg8NX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jdJRUDIF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_jdJRUDIF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7TBoet2M, HV_BINOP_EQ, 1, m, &cBinop_7TBoet2M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qGx3a8ZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pLUfCe0y, HV_BINOP_ADD, 0, m, &cBinop_pLUfCe0y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pLUfCe0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YmC01PcC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EdQSB3B7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jdJRUDIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FQOZIgRD, 1, m, &cIf_FQOZIgRD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7TBoet2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wKcaT0zw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_wKcaT0zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P5y0MbnT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kgsba2hL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_GmIg8bWN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6mmbffN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qGx3a8ZG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qFQkCTSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pLUfCe0y, HV_BINOP_ADD, 1, m, &cBinop_pLUfCe0y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jdJRUDIF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_jdJRUDIF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7TBoet2M, HV_BINOP_EQ, 0, m, &cBinop_7TBoet2M_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9rXGCOKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZCuWE7OH, 0, m, &cVar_ZCuWE7OH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ngyeh0ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ORTeaLfo_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_KHkFZevh, 0, m, &cIf_KHkFZevh_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_KHkFZevh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gX32WEN3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_q13g6XUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pK6ZJUUq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_HnxHmtJC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_3NB0IToj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xYEcZit8, HV_BINOP_POW, 0, m, &cBinop_xYEcZit8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xYEcZit8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lWf3F4vU, 0, m, &cIf_lWf3F4vU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GCaJkPHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Tabnq7ig_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_29jxLzP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IRUv4L5B_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZRo7xi8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q13g6XUs, 0, m, &cIf_q13g6XUs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IRUv4L5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q13g6XUs, 1, m, &cIf_q13g6XUs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HnxHmtJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GCaJkPHW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pK6ZJUUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lWf3F4vU, 0, m, &cIf_lWf3F4vU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tabnq7ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xYEcZit8, HV_BINOP_POW, 1, m, &cBinop_xYEcZit8_sendMessage);
  cMsg_3NB0IToj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_lWf3F4vU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_JmQiuHKg, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_ORTeaLfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KHkFZevh, 1, m, &cIf_KHkFZevh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gX32WEN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vRRBDsQ2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vRRBDsQ2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIZwuNaC, HV_BINOP_EQ, 1, m, &cBinop_iIZwuNaC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gY1Hsi2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MJNb4GD6, HV_BINOP_ADD, 0, m, &cBinop_MJNb4GD6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MJNb4GD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_29jxLzP3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZRo7xi8L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vRRBDsQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lWf3F4vU, 1, m, &cIf_lWf3F4vU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iIZwuNaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LLRpfqgI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_LLRpfqgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JmQiuHKg, m);
}

void Heavy_WSTD_DL3Y::cCast_XrgVegmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ngyeh0ac, 0, m, &cVar_Ngyeh0ac_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OAVNe7Nk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gY1Hsi2j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DP4mpUP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MJNb4GD6, HV_BINOP_ADD, 1, m, &cBinop_MJNb4GD6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vRRBDsQ2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vRRBDsQ2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIZwuNaC, HV_BINOP_EQ, 0, m, &cBinop_iIZwuNaC_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Ll8hwI0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_2Pkg2wrO, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_xYjlaajW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZFlef68p, 0, m, &cSlice_ZFlef68p_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Y7Q7kDzn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ZFlef68p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0F1bFnCe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0F1bFnCe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ghHXe96N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0F1bFnCe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0F1bFnCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ABQH6Iz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Y7Q7kDzn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EGaqDvaW, 0, m, &cSlice_EGaqDvaW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ibKFf8PH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_EGaqDvaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2unxLPe4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2unxLPe4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9qUNI9Ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2unxLPe4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_2unxLPe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UaNNQi3m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KDYhzccP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EaaZCNJE, 0, m, &cSlice_EaaZCNJE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g9hVMfBn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_EaaZCNJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ETbLNFjt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ETbLNFjt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_S7udzymx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ETbLNFjt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ETbLNFjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_13WWtu6B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_g9hVMfBn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_60m6jlIx, 0, m, &cSlice_60m6jlIx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_60m6jlIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7s3etF4o_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7s3etF4o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xug79lXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7s3etF4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7s3etF4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_axOAg1yy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7ZCWYKNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X6SkB0qt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fznaNMVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hlEVM56W, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Pwp9fVe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dOlal1uc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7AEN5hvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IV8gRcXT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xiGNgADY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KlMu4Xnp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RElnjfAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_khqX65dh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_khqX65dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eSOqVG9B, HV_BINOP_DIVIDE, 1, m, &cBinop_eSOqVG9B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oAKaT4B7_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_eooKkpAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_UyhQNg5Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DqpyuUva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eooKkpAd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UyhQNg5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eSOqVG9B, HV_BINOP_DIVIDE, 0, m, &cBinop_eSOqVG9B_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oAKaT4B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DqpyuUva_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eSOqVG9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7gnl2eB, HV_BINOP_MULTIPLY, 1, m, &cBinop_t7gnl2eB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t7gnl2eB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x0WlULpq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JuusMGlo_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_mpx1TNRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DrrXkxRs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_EidJMJAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rbJydCTn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jlF9vrcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_gyTDrWLj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gyTDrWLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7gnl2eB, HV_BINOP_MULTIPLY, 0, m, &cBinop_t7gnl2eB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Khd70FbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_g9x6OJAU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g9x6OJAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YUG2qTQX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qVrpSz69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0lo1UXdm, 1, m, &cVar_0lo1UXdm_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_0lo1UXdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RY7y9hxb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_k6HoXlES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QSIAiIx4, HV_BINOP_MULTIPLY, 1, m, &cBinop_QSIAiIx4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xhEjLgBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_k6HoXlES_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NaHNCsbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Hng94sY4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hng94sY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vPr4ul7c, HV_BINOP_MULTIPLY, 1, m, &cBinop_vPr4ul7c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AP3NeiPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DTFOKtQr, HV_BINOP_MULTIPLY, 1, m, &cBinop_DTFOKtQr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MG6xx9RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AP3NeiPu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QP6onF41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9nGNuXyB, HV_BINOP_MULTIPLY, 1, m, &cBinop_9nGNuXyB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IgkBedCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NyKkgDEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NyKkgDEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ay3bijtw, HV_BINOP_MULTIPLY, 1, m, &cBinop_ay3bijtw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nndcYOA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dS3P9zed_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_jlF9vrcA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nr4PspNc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gKTdoPCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Khd70FbF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_x0WlULpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_mpx1TNRX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JuusMGlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_EidJMJAt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_DrrXkxRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KhFyb1nq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rbJydCTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vdYXKS9n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_z4KrS5DU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_02qdIdsm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YUG2qTQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RGD84S4f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RGD84S4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzeHlptN, HV_BINOP_MULTIPLY, 1, m, &cBinop_MzeHlptN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MzeHlptN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yexVVGj1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yexVVGj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z4KrS5DU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_RY7y9hxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cundpcoR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cundpcoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Il9LscJ5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h2MqjSnu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KOLT1jO3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0X3wpurE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Egjdjexh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pQ3vc9pX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QSIAiIx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7ZCWYKNV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vPr4ul7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fznaNMVh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DTFOKtQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pwp9fVe9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9nGNuXyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7AEN5hvB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ay3bijtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xiGNgADY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sepV5ZJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nndcYOA8, 0, m, &cVar_nndcYOA8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F0jWNqN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gKTdoPCl, 1, m, &cVar_gKTdoPCl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pQ3vc9pX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QSIAiIx4, HV_BINOP_MULTIPLY, 0, m, &cBinop_QSIAiIx4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0X3wpurE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DTFOKtQr, HV_BINOP_MULTIPLY, 0, m, &cBinop_DTFOKtQr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Il9LscJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_Egjdjexh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vPr4ul7c, HV_BINOP_MULTIPLY, 0, m, &cBinop_vPr4ul7c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KOLT1jO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9nGNuXyB, HV_BINOP_MULTIPLY, 0, m, &cBinop_9nGNuXyB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h2MqjSnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ay3bijtw, HV_BINOP_MULTIPLY, 0, m, &cBinop_ay3bijtw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nr4PspNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0lo1UXdm, 0, m, &cVar_0lo1UXdm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dS3P9zed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gKTdoPCl, 0, m, &cVar_gKTdoPCl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0fFPrv48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bMiLZSfL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6MG2fo9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_noGJ8Bs5, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_F64pTdR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y5hvFAve, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5GnSg97C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z5XQCOKO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3C4WFv9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xDpQkksI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xDpQkksI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UMFVd81Q, HV_BINOP_DIVIDE, 1, m, &cBinop_UMFVd81Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vDnZlaya_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Cnr4IYHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_V5pFa5Uv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hhKA1ejk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Cnr4IYHi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V5pFa5Uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UMFVd81Q, HV_BINOP_DIVIDE, 0, m, &cBinop_UMFVd81Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vDnZlaya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhKA1ejk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UMFVd81Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZzFCP7Rk, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZzFCP7Rk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZzFCP7Rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HROoGdhi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_erVfQazf_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_2xRyQAk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RF1gBfq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_onJnz9eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MWUH90Or_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3Al5244G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GoZwahqz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GoZwahqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZzFCP7Rk, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZzFCP7Rk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6kK9lQov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5Y31ijxS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5Y31ijxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Lq6fiZZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YWIDRa2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TQ8aOQa, HV_BINOP_MULTIPLY, 1, m, &cBinop_4TQ8aOQa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_piX8sBMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7sQbJ5xO, 1, m, &cVar_7sQbJ5xO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F9LYoj4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QPHKvK5S, HV_BINOP_MULTIPLY, 1, m, &cBinop_QPHKvK5S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4TC0f3Yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rnvsaTbb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rnvsaTbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h2fIaCUi, HV_BINOP_MULTIPLY, 1, m, &cBinop_h2fIaCUi_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7sQbJ5xO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_joOzQ1FE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_KZLXJnN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PmPiR4u9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3Al5244G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_864VveST_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1zHzHnpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6kK9lQov_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_erVfQazf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_onJnz9eT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HROoGdhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2xRyQAk5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_RF1gBfq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8B3hjd2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MWUH90Or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jR89ybvC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ICw8IKUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DFBQ1Y86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5Lq6fiZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yh9kdU2u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yh9kdU2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_75zaU9nt, HV_BINOP_MULTIPLY, 1, m, &cBinop_75zaU9nt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_75zaU9nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2bQVmBxR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2bQVmBxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ICw8IKUL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_joOzQ1FE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bUvOhjOZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bUvOhjOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OaAV3Wb6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mGiustRA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l5lgCFk1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YvbgQOb3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lj73q1A1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0fFPrv48_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4TQ8aOQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6MG2fo9F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QPHKvK5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F64pTdR7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_h2fIaCUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5GnSg97C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sqO7Tkq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1zHzHnpL, 1, m, &cVar_1zHzHnpL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DpUs0J0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KZLXJnN7, 0, m, &cVar_KZLXJnN7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PmPiR4u9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1zHzHnpL, 0, m, &cVar_1zHzHnpL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_864VveST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7sQbJ5xO, 0, m, &cVar_7sQbJ5xO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mGiustRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QPHKvK5S, HV_BINOP_MULTIPLY, 0, m, &cBinop_QPHKvK5S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YvbgQOb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lj73q1A1, HV_BINOP_MULTIPLY, 0, m, &cBinop_lj73q1A1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OaAV3Wb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h2fIaCUi, HV_BINOP_MULTIPLY, 0, m, &cBinop_h2fIaCUi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l5lgCFk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TQ8aOQa, HV_BINOP_MULTIPLY, 0, m, &cBinop_4TQ8aOQa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jCcrdDGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LiQwFgQD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_plE2dE99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_42cvQX6S, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PYunnYxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gmb4aNSK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GNRvbKpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mz264Jhf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CRDK7CT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lMhigCLd, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WWvIfeuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CHRfzHYH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CHRfzHYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XYvXSc3a, HV_BINOP_DIVIDE, 1, m, &cBinop_XYvXSc3a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dUTFAOcv_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Am3y4cq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_6XJXy9nc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KjNkn7jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Am3y4cq3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6XJXy9nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XYvXSc3a, HV_BINOP_DIVIDE, 0, m, &cBinop_XYvXSc3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dUTFAOcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KjNkn7jk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XYvXSc3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1E3UNTBJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_1E3UNTBJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1E3UNTBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cojlFYP5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xm5yguGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_2sMM6YPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rd21M1Sb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_FbVhPp1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VhUA21l1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KdU31slq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ErPUr3XM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ErPUr3XM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1E3UNTBJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_1E3UNTBJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mgbR7PSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zCzOcVdB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zCzOcVdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j4rxVyt0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tsnBhITJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tX41E7KK, HV_BINOP_MULTIPLY, 1, m, &cBinop_tX41E7KK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_90ZRnGe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pECcivE1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pECcivE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tsnBhITJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J9QK2jsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bh32Hf0H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bh32Hf0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3TZKvfNE, HV_BINOP_MULTIPLY, 1, m, &cBinop_3TZKvfNE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6KA320Qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mh9xQZ8R, HV_BINOP_MULTIPLY, 1, m, &cBinop_Mh9xQZ8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_20Qy5Nvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8YgEsSEY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8YgEsSEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6KA320Qz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X2cGfkJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x0i4aAuz, 1, m, &cVar_x0i4aAuz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lpObJf1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DHKlj39W, HV_BINOP_MULTIPLY, 1, m, &cBinop_DHKlj39W_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kTqjcbwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9p6QxwKr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9p6QxwKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YE8v4wzU, HV_BINOP_MULTIPLY, 1, m, &cBinop_YE8v4wzU_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_x0i4aAuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7g1sM8K3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Lkt0X7Xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bOLWbxgn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_KdU31slq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YdJkJObY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cfvC1gyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mgbR7PSH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Xm5yguGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FbVhPp1W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cojlFYP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2sMM6YPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_rd21M1Sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wBqOnhFn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_VhUA21l1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zULV5ztl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_3rV6lPkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_owScGmPZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_j4rxVyt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_crXyXi1Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_crXyXi1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_enfZRpkA, HV_BINOP_MULTIPLY, 1, m, &cBinop_enfZRpkA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_enfZRpkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EQQrDNcm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EQQrDNcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3rV6lPkp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7g1sM8K3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bPaQIB0M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bPaQIB0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xh1G9VKw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pndHi4hf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ChNPMPaO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sgLfzHQ5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TvPzLuV7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8kfeqY2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tX41E7KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jCcrdDGk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3TZKvfNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_plE2dE99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Mh9xQZ8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYunnYxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DHKlj39W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GNRvbKpZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YE8v4wzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CRDK7CT4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_bT5Cgk4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lkt0X7Xo, 0, m, &cVar_Lkt0X7Xo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eiJ29vh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cfvC1gyI, 1, m, &cVar_cfvC1gyI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sgLfzHQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mh9xQZ8R, HV_BINOP_MULTIPLY, 0, m, &cBinop_Mh9xQZ8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xh1G9VKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_8kfeqY2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tX41E7KK, HV_BINOP_MULTIPLY, 0, m, &cBinop_tX41E7KK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ChNPMPaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DHKlj39W, HV_BINOP_MULTIPLY, 0, m, &cBinop_DHKlj39W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TvPzLuV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3TZKvfNE, HV_BINOP_MULTIPLY, 0, m, &cBinop_3TZKvfNE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pndHi4hf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YE8v4wzU, HV_BINOP_MULTIPLY, 0, m, &cBinop_YE8v4wzU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YdJkJObY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x0i4aAuz, 0, m, &cVar_x0i4aAuz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bOLWbxgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cfvC1gyI, 0, m, &cVar_cfvC1gyI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P5y0MbnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ll8hwI0n, 1, m, &cIf_Ll8hwI0n_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u8e0Wqqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2Pkg2wrO, m);
}

void Heavy_WSTD_DL3Y::cBinop_kgsba2hL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u8e0Wqqi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GmIg8bWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ll8hwI0n, 0, m, &cIf_Ll8hwI0n_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mO4Fqcdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N7W2h1O7, HV_BINOP_DIVIDE, 0, m, &cBinop_N7W2h1O7_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_UeJCTzbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eQcYCHlm, HV_BINOP_DIVIDE, 1, m, &cBinop_eQcYCHlm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_N7W2h1O7, HV_BINOP_DIVIDE, 1, m, &cBinop_N7W2h1O7_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_6hbToFdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLfiDkEP, HV_BINOP_DIVIDE, 0, m, &cBinop_XLfiDkEP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_uyPcstWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLfiDkEP, HV_BINOP_DIVIDE, 1, m, &cBinop_XLfiDkEP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_65Yiq8hX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mO4Fqcdq, 0, m, &cVar_mO4Fqcdq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jz4HeBxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UeJCTzbj, 0, m, &cVar_UeJCTzbj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3NTEMuyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eQcYCHlm, HV_BINOP_DIVIDE, 0, m, &cBinop_eQcYCHlm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eQcYCHlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_6hbToFdW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_N7W2h1O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_uyPcstWj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XLfiDkEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_VtT8vV1w_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_T8vQhx2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_q5J1eXWH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pyz0ieGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_mk4Gx87p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VtT8vV1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Pyz0ieGC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mk4Gx87p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_T8vQhx2R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q5J1eXWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oB4WOeYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_KlP72dZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZhti01T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_EhBVpuiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ek0FlAWp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_G1Z59iCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XGlT7bT0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_uSlzpxjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ORbESrXF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_PrQu9CWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kSctbacl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_TEoo99w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cymF8dQL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_am0fYyba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CaZTMnwe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6UfN2APW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XFSquGfk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_uBD1aHqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8p2cRWWZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BWZ0T9Lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4oP5os1M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Ime6shVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PIs3qdvB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_e8B7yfFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YNhqw2H8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_uJg5R5cz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zEnznjD2, 0, m, &cSlice_zEnznjD2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zEnznjD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0WCJ7COB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0WCJ7COB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_aufUVtsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0WCJ7COB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0WCJ7COB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R7RAs2Im_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_DdPKkAzf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UbZVnYAy, 0, m, &cSlice_UbZVnYAy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uQC8WyOo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_UbZVnYAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wftDAsPy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wftDAsPy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_i4TRNVX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wftDAsPy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_wftDAsPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rl2FVR1I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_nDKfwTzS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Es0XesmA, 0, m, &cSlice_Es0XesmA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uJg5R5cz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Es0XesmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_d2ZOyzXX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_d2ZOyzXX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_X7f4kiAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d2ZOyzXX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_d2ZOyzXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1syAALUa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JzqGmLcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IYfd6goF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IYfd6goF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_bEi01B8m_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_vWix2CTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zDEKqv2v_sendMessage(_c, 0, m);
  cMsg_WS7d30T0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_SLnm2djl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_saYqQCmi_sendMessage(_c, 0, m);
  cMsg_3LG2YQDY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bEi01B8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mtrO1Nsw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mtrO1Nsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y32gRGbT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jq4FrgTd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jq4FrgTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bCW33uiO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_y32gRGbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JgH7rcuE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JgH7rcuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_goBueZ0r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bCW33uiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kYWs0kkF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kYWs0kkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EkeREWPt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_goBueZ0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_vWix2CTw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EkeREWPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_SLnm2djl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vmLWMwN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ycJSTD9u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ycJSTD9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_pY3HRVdP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pY3HRVdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CDJZY0kD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CDJZY0kD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aGrcJypj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RmYXfJ3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RmYXfJ3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_reIRax4Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aGrcJypj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cj3QaXJJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cj3QaXJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6CjtcUYj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_reIRax4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_amicfksB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_amicfksB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AdFtTQgY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AdFtTQgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nvmfjjaD_sendMessage(_c, 0, m);
  cMsg_I4JNfIKF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6CjtcUYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MhSj3OEO_sendMessage(_c, 0, m);
  cMsg_CrtHgojW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qd6NSkBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QZYUx2rb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QZYUx2rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xdjN6Qdi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GWH0I3Nl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_clVkHWx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5oMUrnLJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fP5fzTwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jxy5R211_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_jxy5R211_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oFL0p0af, HV_BINOP_DIVIDE, 1, m, &cBinop_oFL0p0af_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xdjN6Qdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zM8eJrmF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zM8eJrmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GPhYARTr, m);
}

void Heavy_WSTD_DL3Y::cMsg_1umk9ZVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wuAEVYNL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wuAEVYNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qd6NSkBc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GWH0I3Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QBN7SZs6, m);
}

void Heavy_WSTD_DL3Y::cBinop_5oMUrnLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_1m3ecPNj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1m3ecPNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oFL0p0af, HV_BINOP_DIVIDE, 0, m, &cBinop_oFL0p0af_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oFL0p0af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1umk9ZVV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_q8UYW7jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OSdILPjW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OSdILPjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1g7yK59B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9KGZLZ5W_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_K8IajlmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vvcuo0Dv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2V9JUCwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1Ab8c8Yz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_1Ab8c8Yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lUIZ0Mp4, HV_BINOP_DIVIDE, 1, m, &cBinop_lUIZ0Mp4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1g7yK59B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2zX6dgQ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2zX6dgQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WQP5sq2L, m);
}

void Heavy_WSTD_DL3Y::cMsg_IbwRGsoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tJM1tHnr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tJM1tHnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_q8UYW7jo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9KGZLZ5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dolqjpk0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vvcuo0Dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_pGwGxMRE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pGwGxMRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lUIZ0Mp4, HV_BINOP_DIVIDE, 0, m, &cBinop_lUIZ0Mp4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lUIZ0Mp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IbwRGsoY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vS3rOOfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gxF8So82, HV_BINOP_MULTIPLY, 0, m, &cBinop_gxF8So82_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IvCRWIxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fnZX15aJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fnZX15aJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OdpWd8UW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gxF8So82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Kv9DXaHE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qlA4quWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gxF8So82, HV_BINOP_MULTIPLY, 1, m, &cBinop_gxF8So82_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OdpWd8UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qlA4quWd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kv9DXaHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xvIilCPx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xvIilCPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7XgiB6Xp_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iHuAaSxG, m);
}

void Heavy_WSTD_DL3Y::cBinop_7XgiB6Xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DUg41zIx, m);
}

void Heavy_WSTD_DL3Y::cVar_971ISvvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVQ2gl7F, HV_BINOP_MULTIPLY, 0, m, &cBinop_mVQ2gl7F_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_srtiCEDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YkigfOVv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YkigfOVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ccTpYOE1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mVQ2gl7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_U9m8oy2c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OUpE7fS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVQ2gl7F, HV_BINOP_MULTIPLY, 1, m, &cBinop_mVQ2gl7F_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ccTpYOE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OUpE7fS2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U9m8oy2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4cvNOA2P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4cvNOA2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cdbBIQpA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Eq1L04zV, m);
}

void Heavy_WSTD_DL3Y::cBinop_cdbBIQpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CEI8aHd2, m);
}

void Heavy_WSTD_DL3Y::sEnv_YG5JW3qM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sfkQVCHI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3t8Pi4qH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_kxPLMeTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mjUUcexP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_HERXCDLL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_btkWBKiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EoOtN6HZ, HV_BINOP_POW, 0, m, &cBinop_EoOtN6HZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EoOtN6HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aXeJCtHA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TeSu0b4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GR3LLSMd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3t8Pi4qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxPLMeTv, 0, m, &cIf_kxPLMeTv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sfkQVCHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cIeg1IYK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cIeg1IYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxPLMeTv, 1, m, &cIf_kxPLMeTv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HERXCDLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TeSu0b4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mjUUcexP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_aXeJCtHA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GR3LLSMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EoOtN6HZ, HV_BINOP_POW, 1, m, &cBinop_EoOtN6HZ_sendMessage);
  cMsg_btkWBKiR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CGJF1LFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M8DrB4Px, HV_BINOP_MULTIPLY, 0, m, &cBinop_M8DrB4Px_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bWozNsz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PpC3eHn7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PpC3eHn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fG4LDJTe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_M8DrB4Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hOcwz25H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eZzPRZKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M8DrB4Px, HV_BINOP_MULTIPLY, 1, m, &cBinop_M8DrB4Px_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fG4LDJTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eZzPRZKW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hOcwz25H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mGv5EpwX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mGv5EpwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xLiFGzxZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qEpVf039, m);
}

void Heavy_WSTD_DL3Y::cBinop_xLiFGzxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ig0q2iWb, m);
}

void Heavy_WSTD_DL3Y::cMsg_aXeJCtHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5Pjs7V0E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5Pjs7V0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TouNETNv, m);
}

void Heavy_WSTD_DL3Y::sEnv_SPufftx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_frqZNZ2G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uq9IERe6_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_VPFGfrx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_BIL2igc4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_oiXWwJHC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_BK9gC9P3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IecUi3Cg, HV_BINOP_POW, 0, m, &cBinop_IecUi3Cg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IecUi3Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kgh0fd3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TIDs5rEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_kGxQUpxb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Uq9IERe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VPFGfrx6, 0, m, &cIf_VPFGfrx6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_frqZNZ2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qcyNemcA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qcyNemcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VPFGfrx6, 1, m, &cIf_VPFGfrx6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oiXWwJHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TIDs5rEr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BIL2igc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Kgh0fd3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kGxQUpxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IecUi3Cg, HV_BINOP_POW, 1, m, &cBinop_IecUi3Cg_sendMessage);
  cMsg_BK9gC9P3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_bkhmXzJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L060AKfe, HV_BINOP_MULTIPLY, 0, m, &cBinop_L060AKfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oRlneRSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IsiFxNva_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IsiFxNva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I3EQHfKC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_L060AKfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_99xtn3OH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rpjSNrbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L060AKfe, HV_BINOP_MULTIPLY, 1, m, &cBinop_L060AKfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I3EQHfKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rpjSNrbW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_99xtn3OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Hl1JtSq9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hl1JtSq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uGYhgbxV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6HlDSI4u, m);
}

void Heavy_WSTD_DL3Y::cBinop_uGYhgbxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SkutqVR5, m);
}

void Heavy_WSTD_DL3Y::cMsg_Kgh0fd3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NQYSJ5CV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NQYSJ5CV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QnCJP76l, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_uQC8WyOo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ma1HcgvI, 0, m, &cSlice_ma1HcgvI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nDKfwTzS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ma1HcgvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tSGFLeRP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tSGFLeRP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_SxRafSm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tSGFLeRP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_tSGFLeRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RuSxj0LV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_bJ3aMUFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xHRRCIdM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xHRRCIdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Rigr7Kb7_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_cgZD5voh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cgZD5voh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pNPbDaGT, 0, m, &cDelay_pNPbDaGT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cgZD5voh, 0, m, &cDelay_cgZD5voh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yRd2oXvf, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_pNPbDaGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pNPbDaGT, m);
  cMsg_TMCuQT5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_dr3N2KaE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mBIvZe34_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_AnaJ1Rx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AUz88vtY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_4RT7wBYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vzYCRvNx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cgZD5voh, 2, m, &cDelay_cgZD5voh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kGM3mg6p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AUz88vtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_4RT7wBYD, 0, m, &hTable_4RT7wBYD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rigr7Kb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_AnaJ1Rx2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TMCuQT5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_4RT7wBYD, 0, m, &hTable_4RT7wBYD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kGM3mg6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cgZD5voh, 0, m, &cDelay_cgZD5voh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vzYCRvNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_pNPbDaGT, 2, m, &cDelay_pNPbDaGT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mBIvZe34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yRd2oXvf, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_mP322oaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H4apkJBN, HV_BINOP_SUBTRACT, 0, m, &cBinop_H4apkJBN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Uucd5rak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fXiSOQE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fXiSOQE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KQs1lhJC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nDt8bQRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cPXAdM3a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_kiCy6LU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kiCy6LU9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dqtjAmjB, 0, m, &cDelay_dqtjAmjB_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qtYBFBNz, 0, m, &sTabread_qtYBFBNz_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_dqtjAmjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dqtjAmjB, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qtYBFBNz, 0, m, &sTabread_qtYBFBNz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dqtjAmjB, 0, m, &cDelay_dqtjAmjB_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_qtYBFBNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_tB8Qn3gC, HV_BINOP_SUBTRACT, 0, m, &cBinop_tB8Qn3gC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_dFERwm9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_izB1rLCR, HV_BINOP_MAX, 0, m, &cBinop_izB1rLCR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KQs1lhJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dFERwm9d, HV_BINOP_MULTIPLY, 0, m, &cBinop_dFERwm9d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H4apkJBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W4vORVTT_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qtYBFBNz, 0, m, &sTabread_qtYBFBNz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SSgah9Yb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EAcK8FPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tB8Qn3gC, HV_BINOP_SUBTRACT, 1, m, &cBinop_tB8Qn3gC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dqtjAmjB, 2, m, &cDelay_dqtjAmjB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cPXAdM3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EAcK8FPJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W4vORVTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kiCy6LU9, 0, m, &cDelay_kiCy6LU9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dqtjAmjB, 0, m, &cDelay_dqtjAmjB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ouo98YJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_izB1rLCR, HV_BINOP_MAX, 1, m, &cBinop_izB1rLCR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_izB1rLCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H4apkJBN, HV_BINOP_SUBTRACT, 1, m, &cBinop_H4apkJBN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SSgah9Yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kiCy6LU9, 0, m, &cDelay_kiCy6LU9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WuklVTXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kiCy6LU9, 2, m, &cDelay_kiCy6LU9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tB8Qn3gC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WuklVTXX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6NpqY6tY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nDt8bQRO, 0, m, &cVar_nDt8bQRO_sendMessage);
  cMsg_Uucd5rak_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mP322oaN, 0, m, &cTabhead_mP322oaN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jPU8J6Pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rH8E4Ysi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_rH8E4Ysi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Z5NZCXgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_k57PynYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_k57PynYu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wrS9M75r, 0, m, &cDelay_wrS9M75r_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_k57PynYu, 0, m, &cDelay_k57PynYu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LRerAZqE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_wrS9M75r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wrS9M75r, m);
  cMsg_9z8eXX9D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_1iFDHDIV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ciPIQutg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_4LuCR982_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_czz9Kp5d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_53FRlMRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a6XpuN35_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_k57PynYu, 2, m, &cDelay_k57PynYu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AgZKNi6k_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_czz9Kp5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_53FRlMRA, 0, m, &hTable_53FRlMRA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z5NZCXgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_4LuCR982_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9z8eXX9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_53FRlMRA, 0, m, &hTable_53FRlMRA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AgZKNi6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_k57PynYu, 0, m, &cDelay_k57PynYu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_a6XpuN35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wrS9M75r, 2, m, &cDelay_wrS9M75r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ciPIQutg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LRerAZqE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_M1GclX0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Li808Xeh, HV_BINOP_SUBTRACT, 0, m, &cBinop_Li808Xeh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jRdoevrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_V18A4taA_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_V18A4taA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Nh1zvsQu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8sOvARzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xCnjVRfM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_GJ6vOKdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GJ6vOKdX, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_af3DA8PY, 0, m, &cDelay_af3DA8PY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PuHz1jA1, 0, m, &sTabread_PuHz1jA1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_af3DA8PY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_af3DA8PY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PuHz1jA1, 0, m, &sTabread_PuHz1jA1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_af3DA8PY, 0, m, &cDelay_af3DA8PY_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_PuHz1jA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_EVQDimhW, HV_BINOP_SUBTRACT, 0, m, &cBinop_EVQDimhW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_qLZrWkYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gYQ0TuuK, HV_BINOP_MAX, 0, m, &cBinop_gYQ0TuuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nh1zvsQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qLZrWkYL, HV_BINOP_MULTIPLY, 0, m, &cBinop_qLZrWkYL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Li808Xeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JyeYgNFs_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PuHz1jA1, 0, m, &sTabread_PuHz1jA1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_19dHevtI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_9k71ypnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EVQDimhW, HV_BINOP_SUBTRACT, 1, m, &cBinop_EVQDimhW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_af3DA8PY, 2, m, &cDelay_af3DA8PY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xCnjVRfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9k71ypnA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JyeYgNFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GJ6vOKdX, 0, m, &cDelay_GJ6vOKdX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_af3DA8PY, 0, m, &cDelay_af3DA8PY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lomVFOgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_gYQ0TuuK, HV_BINOP_MAX, 1, m, &cBinop_gYQ0TuuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gYQ0TuuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Li808Xeh, HV_BINOP_SUBTRACT, 1, m, &cBinop_Li808Xeh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_19dHevtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GJ6vOKdX, 0, m, &cDelay_GJ6vOKdX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_na4TXuNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GJ6vOKdX, 2, m, &cDelay_GJ6vOKdX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EVQDimhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_na4TXuNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gBplESYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8sOvARzH, 0, m, &cVar_8sOvARzH_sendMessage);
  cMsg_jRdoevrk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_M1GclX0t, 0, m, &cTabhead_M1GclX0t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zDEKqv2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6vvtxlCT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_saYqQCmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PrtZ0oGD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3LG2YQDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5AzsYKWF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WS7d30T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2tYUzbyE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CrtHgojW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z7ex0L7N, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nvmfjjaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9AUnoLtp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_MhSj3OEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jRTTgQzQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_I4JNfIKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xccofcGN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_nnc54fyB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_R1R0odHB, 0, m, &cSlice_R1R0odHB_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_R1R0odHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xuKHASEo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xuKHASEo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Y5N5TASe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xuKHASEo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xuKHASEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8A9rf8Sw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_IVzVfGMY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2110VYRw, 0, m, &cSlice_2110VYRw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lDVVpZYX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_2110VYRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gxYIc2fA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gxYIc2fA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_kaDhFWoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gxYIc2fA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gxYIc2fA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xNlGnxRW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8WRI6UKj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_m9QLaDg1, 0, m, &cSlice_m9QLaDg1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nnc54fyB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_m9QLaDg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nSTqEHx8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nSTqEHx8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pcuyoBHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nSTqEHx8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nSTqEHx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NBIhRw3L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zbCYO5pD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_30Uw8dA0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_30Uw8dA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_iw7xMnzK_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_cV9Rjq5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YfJ7GvC3_sendMessage(_c, 0, m);
  cMsg_ikG3FTsf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_V6MCGDqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EkD968R8_sendMessage(_c, 0, m);
  cMsg_uqwe8w8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iw7xMnzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QebGo4qI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QebGo4qI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9a6hj6Nv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fl1LejZj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fl1LejZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R6lUyLz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9a6hj6Nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8tHvdCu4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8tHvdCu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LGY56V6i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R6lUyLz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HjHOPZxE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HjHOPZxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JZo1vW3o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LGY56V6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_cV9Rjq5V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JZo1vW3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_V6MCGDqx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GS5TXSpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wvCcrLLm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wvCcrLLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_GFnAPzo6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GFnAPzo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_malrZgvW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_malrZgvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3BAwlc2c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rJorTC4Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rJorTC4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bxgZrFOK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3BAwlc2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zLCKR0Yb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zLCKR0Yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ilfvheBv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bxgZrFOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZLap7XPd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZLap7XPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RucEg2BW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RucEg2BW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yphhSKP0_sendMessage(_c, 0, m);
  cMsg_QZwj6kvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ilfvheBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mKFqQ8kN_sendMessage(_c, 0, m);
  cMsg_WaM6l2Xy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Z2vnBVuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0STycute_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0STycute_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eVq1F3DU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wzW44oJ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7OwCZxc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_w16COC7M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xDnof6oU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_o3vr6nFi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_o3vr6nFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cRENwh3u, HV_BINOP_DIVIDE, 1, m, &cBinop_cRENwh3u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eVq1F3DU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DPPkrq1N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DPPkrq1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VME72CB5, m);
}

void Heavy_WSTD_DL3Y::cMsg_ITTWkd01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nVn4VQzE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nVn4VQzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Z2vnBVuV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wzW44oJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ehM1n0Tj, m);
}

void Heavy_WSTD_DL3Y::cBinop_w16COC7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_iRh4c3v2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iRh4c3v2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cRENwh3u, HV_BINOP_DIVIDE, 0, m, &cBinop_cRENwh3u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cRENwh3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ITTWkd01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2hSkdBLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pIuHcWya_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pIuHcWya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_z8yUstLi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Br6gZFy1_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_29y5FrVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_4a4XGv5d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tuQQBWAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aGxzIkI2_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_aGxzIkI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jtKCDY0e, HV_BINOP_DIVIDE, 1, m, &cBinop_jtKCDY0e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z8yUstLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5GMQodba_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5GMQodba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_w3oxMSC7, m);
}

void Heavy_WSTD_DL3Y::cMsg_d3aCH7gX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_REy23i2K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_REy23i2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2hSkdBLa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Br6gZFy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RIgLIP4l, m);
}

void Heavy_WSTD_DL3Y::cBinop_4a4XGv5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_G5zWzzDS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G5zWzzDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jtKCDY0e, HV_BINOP_DIVIDE, 0, m, &cBinop_jtKCDY0e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jtKCDY0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d3aCH7gX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_jHr3jXLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R49cN8nF, HV_BINOP_MULTIPLY, 0, m, &cBinop_R49cN8nF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YPLm1dkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cyYypX94_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cyYypX94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XgANRd0D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_R49cN8nF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bdM1C0el_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aZAZBjIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R49cN8nF, HV_BINOP_MULTIPLY, 1, m, &cBinop_R49cN8nF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XgANRd0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aZAZBjIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bdM1C0el_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8vjZNaYi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8vjZNaYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_THSypl0K_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_C1IBS9qV, m);
}

void Heavy_WSTD_DL3Y::cBinop_THSypl0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Edfj2HRe, m);
}

void Heavy_WSTD_DL3Y::cVar_CXvek7WL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RpKWGveH, HV_BINOP_MULTIPLY, 0, m, &cBinop_RpKWGveH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tvTOSdNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oSqh27UP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oSqh27UP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fFr9iddl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RpKWGveH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Zu775sM5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_85C2PXVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RpKWGveH, HV_BINOP_MULTIPLY, 1, m, &cBinop_RpKWGveH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fFr9iddl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_85C2PXVN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zu775sM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nwxssYBZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nwxssYBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_k6r1KBQs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xy0pJ8Km, m);
}

void Heavy_WSTD_DL3Y::cBinop_k6r1KBQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8i7I6oih, m);
}

void Heavy_WSTD_DL3Y::sEnv_FqrPj7Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0AqSeEfH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bBLlDQFw_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_dRwS10lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wcUyfosE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_SGtcwwx7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_cPlzOKir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4cZCLcsy, HV_BINOP_POW, 0, m, &cBinop_4cZCLcsy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4cZCLcsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GNAqsUJE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fTfvDiBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2REJileS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bBLlDQFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dRwS10lm, 0, m, &cIf_dRwS10lm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0AqSeEfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9jCVBiCs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9jCVBiCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dRwS10lm, 1, m, &cIf_dRwS10lm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SGtcwwx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fTfvDiBu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wcUyfosE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_GNAqsUJE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2REJileS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4cZCLcsy, HV_BINOP_POW, 1, m, &cBinop_4cZCLcsy_sendMessage);
  cMsg_cPlzOKir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JJS60vaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MaEMOu7t, HV_BINOP_MULTIPLY, 0, m, &cBinop_MaEMOu7t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SiqraxlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Iv3QjI9u_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Iv3QjI9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EG0nKe9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MaEMOu7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UCMVMmxA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hKxUSci9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MaEMOu7t, HV_BINOP_MULTIPLY, 1, m, &cBinop_MaEMOu7t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EG0nKe9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hKxUSci9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UCMVMmxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_U6NAdUVE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U6NAdUVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_laIQfhiT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_D3kKcMEt, m);
}

void Heavy_WSTD_DL3Y::cBinop_laIQfhiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OQkyyzXS, m);
}

void Heavy_WSTD_DL3Y::cMsg_GNAqsUJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ht8QbviR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ht8QbviR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VYEmcgEk, m);
}

void Heavy_WSTD_DL3Y::sEnv_IH28Stkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KR9uvNa3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xLLOmMJo_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_sqNY7CWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_omgUZkdu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VP6KswyZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JQIjoxmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HkaNB7eW, HV_BINOP_POW, 0, m, &cBinop_HkaNB7eW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HkaNB7eW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CAFE0Md8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1dD7tFnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1WeFdzF5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xLLOmMJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sqNY7CWn, 0, m, &cIf_sqNY7CWn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KR9uvNa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_g60LKRme_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g60LKRme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sqNY7CWn, 1, m, &cIf_sqNY7CWn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VP6KswyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1dD7tFnt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_omgUZkdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_CAFE0Md8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1WeFdzF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HkaNB7eW, HV_BINOP_POW, 1, m, &cBinop_HkaNB7eW_sendMessage);
  cMsg_JQIjoxmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QYAZVMtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9O0eZbhB, HV_BINOP_MULTIPLY, 0, m, &cBinop_9O0eZbhB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qA3fA0CO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RDLD5Bjc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RDLD5Bjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MLtJCYrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9O0eZbhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mfXpgHiv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bXWJbV5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9O0eZbhB, HV_BINOP_MULTIPLY, 1, m, &cBinop_9O0eZbhB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MLtJCYrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bXWJbV5v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mfXpgHiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SZM7vwsG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SZM7vwsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OJCcxsPS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aMD6959m, m);
}

void Heavy_WSTD_DL3Y::cBinop_OJCcxsPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_p9ZiHA4h, m);
}

void Heavy_WSTD_DL3Y::cMsg_CAFE0Md8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eqwlyKhl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eqwlyKhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_c4bbhSlr, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_lDVVpZYX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XaVp0IRR, 0, m, &cSlice_XaVp0IRR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8WRI6UKj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XaVp0IRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z6pZnLX2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z6pZnLX2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_KQ35b6SB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z6pZnLX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Z6pZnLX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5LcZgoEx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1SVrano7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rCK9Uj38_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_rCK9Uj38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Zq4XTsVV_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_DCAHKnuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DCAHKnuS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0WapkC5U, 0, m, &cDelay_0WapkC5U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DCAHKnuS, 0, m, &cDelay_DCAHKnuS_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oHkOsNvn, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_0WapkC5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0WapkC5U, m);
  cMsg_T28Y8NZj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Td2bVPEv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_uD3o33cr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_ZyQ1azy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_48eptqBw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_DQ5Vyiir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cANkTRQh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DCAHKnuS, 2, m, &cDelay_DCAHKnuS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aerlGyiJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_48eptqBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DQ5Vyiir, 0, m, &hTable_DQ5Vyiir_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zq4XTsVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_ZyQ1azy2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T28Y8NZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DQ5Vyiir, 0, m, &hTable_DQ5Vyiir_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aerlGyiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DCAHKnuS, 0, m, &cDelay_DCAHKnuS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cANkTRQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_0WapkC5U, 2, m, &cDelay_0WapkC5U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uD3o33cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oHkOsNvn, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_nTffNHYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htUCZ4zF, HV_BINOP_SUBTRACT, 0, m, &cBinop_htUCZ4zF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UrPk7Ikx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VfIjY4af_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VfIjY4af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_m3U0fl32_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8R1r3GfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sza6G8vO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_pU3CSZ1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pU3CSZ1H, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSWT7EAo, 0, m, &cDelay_tSWT7EAo_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bDtyNDwy, 0, m, &sTabread_bDtyNDwy_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tSWT7EAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tSWT7EAo, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bDtyNDwy, 0, m, &sTabread_bDtyNDwy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSWT7EAo, 0, m, &cDelay_tSWT7EAo_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_bDtyNDwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_OnGPKqzk, HV_BINOP_SUBTRACT, 0, m, &cBinop_OnGPKqzk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_uRnFoNJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uV9q2HKe, HV_BINOP_MAX, 0, m, &cBinop_uV9q2HKe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m3U0fl32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uRnFoNJd, HV_BINOP_MULTIPLY, 0, m, &cBinop_uRnFoNJd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_htUCZ4zF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2d7KNe7H_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bDtyNDwy, 0, m, &sTabread_bDtyNDwy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SoijrL8Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_97TJU71Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OnGPKqzk, HV_BINOP_SUBTRACT, 1, m, &cBinop_OnGPKqzk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSWT7EAo, 2, m, &cDelay_tSWT7EAo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Sza6G8vO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_97TJU71Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2d7KNe7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pU3CSZ1H, 0, m, &cDelay_pU3CSZ1H_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSWT7EAo, 0, m, &cDelay_tSWT7EAo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GSFEtPRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_uV9q2HKe, HV_BINOP_MAX, 1, m, &cBinop_uV9q2HKe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uV9q2HKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htUCZ4zF, HV_BINOP_SUBTRACT, 1, m, &cBinop_htUCZ4zF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SoijrL8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pU3CSZ1H, 0, m, &cDelay_pU3CSZ1H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lDuQz5OV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pU3CSZ1H, 2, m, &cDelay_pU3CSZ1H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OnGPKqzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lDuQz5OV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7WmpIDn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8R1r3GfX, 0, m, &cVar_8R1r3GfX_sendMessage);
  cMsg_UrPk7Ikx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nTffNHYv, 0, m, &cTabhead_nTffNHYv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nKUGGNM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0OwrZrET_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0OwrZrET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kVUwJlp9_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Xxxv7RGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xxxv7RGj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uDLiULvN, 0, m, &cDelay_uDLiULvN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xxxv7RGj, 0, m, &cDelay_Xxxv7RGj_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PdEEiYqK, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_uDLiULvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uDLiULvN, m);
  cMsg_dHpKAMqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qrV5cYP6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_jTxycH6J_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_bpmpXfyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lqdbZ8tJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_QYF8GaNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uk4K9Jmq_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xxxv7RGj, 2, m, &cDelay_Xxxv7RGj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MocWzl2s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lqdbZ8tJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_QYF8GaNM, 0, m, &hTable_QYF8GaNM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kVUwJlp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_bpmpXfyR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dHpKAMqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_QYF8GaNM, 0, m, &hTable_QYF8GaNM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MocWzl2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xxxv7RGj, 0, m, &cDelay_Xxxv7RGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uk4K9Jmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_uDLiULvN, 2, m, &cDelay_uDLiULvN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jTxycH6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PdEEiYqK, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_Ghe7FRaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8r1fured, HV_BINOP_SUBTRACT, 0, m, &cBinop_8r1fured_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ziiH9h8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Jg2flVVV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Jg2flVVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_d9k7j4ke_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MyF71C90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VQ5Py7eE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_NgjKR9B5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NgjKR9B5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ANA7hJG8, 0, m, &cDelay_ANA7hJG8_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_g5HOcDJY, 0, m, &sTabread_g5HOcDJY_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ANA7hJG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ANA7hJG8, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_g5HOcDJY, 0, m, &sTabread_g5HOcDJY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ANA7hJG8, 0, m, &cDelay_ANA7hJG8_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_g5HOcDJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YzD2q73D, HV_BINOP_SUBTRACT, 0, m, &cBinop_YzD2q73D_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_pZnVhTXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hyf6V3tW, HV_BINOP_MAX, 0, m, &cBinop_Hyf6V3tW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d9k7j4ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pZnVhTXy, HV_BINOP_MULTIPLY, 0, m, &cBinop_pZnVhTXy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8r1fured_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dF4RIhbc_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_g5HOcDJY, 0, m, &sTabread_g5HOcDJY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HQNZ1BV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vR80nEQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YzD2q73D, HV_BINOP_SUBTRACT, 1, m, &cBinop_YzD2q73D_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ANA7hJG8, 2, m, &cDelay_ANA7hJG8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VQ5Py7eE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vR80nEQK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dF4RIhbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NgjKR9B5, 0, m, &cDelay_NgjKR9B5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ANA7hJG8, 0, m, &cDelay_ANA7hJG8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zr3c5naw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hyf6V3tW, HV_BINOP_MAX, 1, m, &cBinop_Hyf6V3tW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hyf6V3tW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8r1fured, HV_BINOP_SUBTRACT, 1, m, &cBinop_8r1fured_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HQNZ1BV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NgjKR9B5, 0, m, &cDelay_NgjKR9B5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DhwvXMGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NgjKR9B5, 2, m, &cDelay_NgjKR9B5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YzD2q73D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DhwvXMGC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_g9A6MLrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MyF71C90, 0, m, &cVar_MyF71C90_sendMessage);
  cMsg_ziiH9h8y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Ghe7FRaA, 0, m, &cTabhead_Ghe7FRaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YfJ7GvC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s3wZsadc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EkD968R8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BDpGbARy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uqwe8w8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SvVixzbw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ikG3FTsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GeFHToa6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WaM6l2Xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tH7vOrtF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yphhSKP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7hDTQupF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mKFqQ8kN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cZfhy0zA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QZwj6kvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i5SdvvvW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_fgtJBciW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U9s6J2ag, 0, m, &cSlice_U9s6J2ag_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_U9s6J2ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4ozEjgwO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4ozEjgwO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_X13MR2Rt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4ozEjgwO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_4ozEjgwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Bf1i9WFZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KcTSU0jD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NBxUF6Vj, 0, m, &cSlice_NBxUF6Vj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5oKYDrKW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_NBxUF6Vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8NF3m8jQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8NF3m8jQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_jAWVpFLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8NF3m8jQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_8NF3m8jQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VynHoDs6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_N8cxkFVo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NIvpV3Kc, 0, m, &cSlice_NIvpV3Kc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fgtJBciW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_NIvpV3Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pSUN7n8o_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pSUN7n8o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QFuhcyby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pSUN7n8o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pSUN7n8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DAsxlMQV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LsuIjASs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KzgTVPTP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KzgTVPTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_7w2AaeE2_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_xwskMVwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PpCteJN6_sendMessage(_c, 0, m);
  cMsg_lFBZ0AN7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_dLduCBsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QCsxydrI_sendMessage(_c, 0, m);
  cMsg_mfbpXeZb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7w2AaeE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RE8Sp75G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RE8Sp75G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hFZsS0oE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0sbS6Blv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0sbS6Blv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_edEcCscE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hFZsS0oE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_65wb6gmv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_65wb6gmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PYVF4oNm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_edEcCscE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VDusQMko_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VDusQMko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WOFdYvt5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PYVF4oNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_xwskMVwi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WOFdYvt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_dLduCBsU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e9cTntek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2G5caxZm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2G5caxZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TR0zM5IT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TR0zM5IT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MzL4AhlG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MzL4AhlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IR8KPGwx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0m4Bs8nM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0m4Bs8nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_26nbScm6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IR8KPGwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hbnDhgAg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hbnDhgAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_40p7oxT3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_26nbScm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZniBLTRr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZniBLTRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Y3rNNKHE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y3rNNKHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZWSuebiM_sendMessage(_c, 0, m);
  cMsg_mS4x5wDH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_40p7oxT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D37Trl8G_sendMessage(_c, 0, m);
  cMsg_TaiNN5YK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1j0NdUFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Ho5X04zq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ho5X04zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RurdYo6W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SrLcUVu0_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MqAiXUAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_yiAPdvwO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EblcbFIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_M5nNNPe3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_M5nNNPe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2GAB42dT, HV_BINOP_DIVIDE, 1, m, &cBinop_2GAB42dT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RurdYo6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yxZZFvIv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yxZZFvIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_H9kF90De, m);
}

void Heavy_WSTD_DL3Y::cMsg_oSpJ2LNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BdBIakHM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BdBIakHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1j0NdUFY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SrLcUVu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_55TTeHmd, m);
}

void Heavy_WSTD_DL3Y::cBinop_yiAPdvwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Extpuy3x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Extpuy3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2GAB42dT, HV_BINOP_DIVIDE, 0, m, &cBinop_2GAB42dT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2GAB42dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oSpJ2LNK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nR3SYhAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IEkB9HKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IEkB9HKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BQ9ncbFm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mF6mrpmW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BDs7NsPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_DebvxQGV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VfBbF17a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zM5huVkx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_zM5huVkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7fyfHX5p, HV_BINOP_DIVIDE, 1, m, &cBinop_7fyfHX5p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BQ9ncbFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ak0wslp1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ak0wslp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_H7IJF0p8, m);
}

void Heavy_WSTD_DL3Y::cMsg_f4r4H3gI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bw8CWZrV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bw8CWZrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nR3SYhAa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mF6mrpmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_e3FpJZQ8, m);
}

void Heavy_WSTD_DL3Y::cBinop_DebvxQGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_j37M7LKB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j37M7LKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7fyfHX5p, HV_BINOP_DIVIDE, 0, m, &cBinop_7fyfHX5p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7fyfHX5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f4r4H3gI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_PufZaAAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t3YPnRSw, HV_BINOP_MULTIPLY, 0, m, &cBinop_t3YPnRSw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MngXBp1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_624cDlrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_624cDlrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Hxjkkal_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_t3YPnRSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KBqfe0jI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1pKs9YTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t3YPnRSw, HV_BINOP_MULTIPLY, 1, m, &cBinop_t3YPnRSw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9Hxjkkal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1pKs9YTj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KBqfe0jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0D5D805C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0D5D805C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LpUtysvf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iRxYRSYl, m);
}

void Heavy_WSTD_DL3Y::cBinop_LpUtysvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_b7cQaKsN, m);
}

void Heavy_WSTD_DL3Y::cVar_uq11AUSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XXVvpyC, HV_BINOP_MULTIPLY, 0, m, &cBinop_8XXVvpyC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hGYFvSVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bPIPfeYK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bPIPfeYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w0hnmPON_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8XXVvpyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_RduXDydi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pp3KxhtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XXVvpyC, HV_BINOP_MULTIPLY, 1, m, &cBinop_8XXVvpyC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_w0hnmPON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pp3KxhtM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RduXDydi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mJuaIrd7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mJuaIrd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_T0szhuE7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_j0tWJvbN, m);
}

void Heavy_WSTD_DL3Y::cBinop_T0szhuE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5rkpezbR, m);
}

void Heavy_WSTD_DL3Y::sEnv_yWpweweR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zmFYhbGu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ftekGS1T_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_8GfQdgfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_rh5FVHl9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_8EBkU9q7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_7tAlHayU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_axXbv7RJ, HV_BINOP_POW, 0, m, &cBinop_axXbv7RJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_axXbv7RJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dHxLtku0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OnaUO4xS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ffUA0d2X_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zmFYhbGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vmNkgn0i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ftekGS1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8GfQdgfH, 0, m, &cIf_8GfQdgfH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vmNkgn0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8GfQdgfH, 1, m, &cIf_8GfQdgfH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8EBkU9q7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_OnaUO4xS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rh5FVHl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_dHxLtku0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ffUA0d2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_axXbv7RJ, HV_BINOP_POW, 1, m, &cBinop_axXbv7RJ_sendMessage);
  cMsg_7tAlHayU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_fllZJJZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QVackeBE, HV_BINOP_MULTIPLY, 0, m, &cBinop_QVackeBE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IETo5XLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7IJuLfk8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7IJuLfk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5CziuvR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QVackeBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_M4IwB5Po_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_phFkPukg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QVackeBE, HV_BINOP_MULTIPLY, 1, m, &cBinop_QVackeBE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5CziuvR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_phFkPukg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M4IwB5Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_c9pRdupv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c9pRdupv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Sa0sk01L_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CKBnMWEE, m);
}

void Heavy_WSTD_DL3Y::cBinop_Sa0sk01L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bnEfwBc5, m);
}

void Heavy_WSTD_DL3Y::cMsg_dHxLtku0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QA8FO4jb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QA8FO4jb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_X37SBS4D, m);
}

void Heavy_WSTD_DL3Y::sEnv_4snyFlJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zwJ79UuN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NmsHsRRI_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_awXaDY6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YZBZ7GJh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FfR5AcvI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_kUnoDwWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6cJsioaY, HV_BINOP_POW, 0, m, &cBinop_6cJsioaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6cJsioaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_snuAsmwd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_U6IKCVcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Ctas0yMS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zwJ79UuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VyjBOQOj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NmsHsRRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_awXaDY6t, 0, m, &cIf_awXaDY6t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VyjBOQOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_awXaDY6t, 1, m, &cIf_awXaDY6t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FfR5AcvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_U6IKCVcm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YZBZ7GJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_snuAsmwd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ctas0yMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6cJsioaY, HV_BINOP_POW, 1, m, &cBinop_6cJsioaY_sendMessage);
  cMsg_kUnoDwWE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_bIc6VeQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bqx4eDho, HV_BINOP_MULTIPLY, 0, m, &cBinop_Bqx4eDho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bpR3ZwoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_R7WwvZ4q_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_R7WwvZ4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BLFPHGEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Bqx4eDho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_kL5KmLlC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eiOZ236a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bqx4eDho, HV_BINOP_MULTIPLY, 1, m, &cBinop_Bqx4eDho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BLFPHGEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eiOZ236a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kL5KmLlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_d4ZV2RDq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d4ZV2RDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kzvtaeWZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1BmDoouT, m);
}

void Heavy_WSTD_DL3Y::cBinop_kzvtaeWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AlWM4wZy, m);
}

void Heavy_WSTD_DL3Y::cMsg_snuAsmwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3n7Gb1FB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3n7Gb1FB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CCiOsY7B, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5oKYDrKW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TpZj30Zv, 0, m, &cSlice_TpZj30Zv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_N8cxkFVo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_TpZj30Zv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ge4XOF6E_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ge4XOF6E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_3VEIbLft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ge4XOF6E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ge4XOF6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bOtZ65lP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_LmYpHARm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EdxFrdEy_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EdxFrdEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yxx4GqHF_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_t4x0nW3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_t4x0nW3q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u4QrhoXP, 0, m, &cDelay_u4QrhoXP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_t4x0nW3q, 0, m, &cDelay_t4x0nW3q_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_aYXx9EZk, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_u4QrhoXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u4QrhoXP, m);
  cMsg_Wim68ADg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_1dvXU07K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Z0FboK6P_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Ku9fJrZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZS4Rhtqy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_YKt2ghxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RoKBWGMS_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_t4x0nW3q, 2, m, &cDelay_t4x0nW3q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6GQ5TRMS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZS4Rhtqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YKt2ghxW, 0, m, &hTable_YKt2ghxW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yxx4GqHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Ku9fJrZe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wim68ADg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YKt2ghxW, 0, m, &hTable_YKt2ghxW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6GQ5TRMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_t4x0nW3q, 0, m, &cDelay_t4x0nW3q_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RoKBWGMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_u4QrhoXP, 2, m, &cDelay_u4QrhoXP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Z0FboK6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_aYXx9EZk, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_GvFFjUM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q2gSv8Ub, HV_BINOP_SUBTRACT, 0, m, &cBinop_Q2gSv8Ub_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zHdAk2q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7uwVqeu8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7uwVqeu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_k6V8aHDA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_YcXXOJls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z5NtVXcn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_TF3bQk8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TF3bQk8l, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_htO5S82y, 0, m, &cDelay_htO5S82y_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B8XWFxj1, 0, m, &sTabread_B8XWFxj1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_htO5S82y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_htO5S82y, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B8XWFxj1, 0, m, &sTabread_B8XWFxj1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_htO5S82y, 0, m, &cDelay_htO5S82y_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_B8XWFxj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_b8sDN3zB, HV_BINOP_SUBTRACT, 0, m, &cBinop_b8sDN3zB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_0Lndy6LB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_etns9R6w, HV_BINOP_MAX, 0, m, &cBinop_etns9R6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k6V8aHDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Lndy6LB, HV_BINOP_MULTIPLY, 0, m, &cBinop_0Lndy6LB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q2gSv8Ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Du47lOF3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B8XWFxj1, 0, m, &sTabread_B8XWFxj1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oc0c7bBu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PANGfrNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b8sDN3zB, HV_BINOP_SUBTRACT, 1, m, &cBinop_b8sDN3zB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_htO5S82y, 2, m, &cDelay_htO5S82y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Z5NtVXcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PANGfrNL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Du47lOF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TF3bQk8l, 0, m, &cDelay_TF3bQk8l_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_htO5S82y, 0, m, &cDelay_htO5S82y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FjjGVcuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_etns9R6w, HV_BINOP_MAX, 1, m, &cBinop_etns9R6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_etns9R6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q2gSv8Ub, HV_BINOP_SUBTRACT, 1, m, &cBinop_Q2gSv8Ub_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Oc0c7bBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TF3bQk8l, 0, m, &cDelay_TF3bQk8l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_efPMsfYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TF3bQk8l, 2, m, &cDelay_TF3bQk8l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b8sDN3zB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_efPMsfYP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h7LZxvl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YcXXOJls, 0, m, &cVar_YcXXOJls_sendMessage);
  cMsg_zHdAk2q1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_GvFFjUM4, 0, m, &cTabhead_GvFFjUM4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1E25FUY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Cq8fhW3E_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Cq8fhW3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yBrAIetb_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_aIsfMUNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aIsfMUNh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a2m3hGAn, 0, m, &cDelay_a2m3hGAn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aIsfMUNh, 0, m, &cDelay_aIsfMUNh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DhQVDVdp, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_a2m3hGAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a2m3hGAn, m);
  cMsg_yN7jOknt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zXMJS9Pp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_9PPMwDqc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_zuyH3GWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KZTpWZmS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_jzM1zqD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GCJqTpbE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aIsfMUNh, 2, m, &cDelay_aIsfMUNh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aJbPpaYO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KZTpWZmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_jzM1zqD6, 0, m, &hTable_jzM1zqD6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yBrAIetb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_zuyH3GWm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yN7jOknt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_jzM1zqD6, 0, m, &hTable_jzM1zqD6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aJbPpaYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aIsfMUNh, 0, m, &cDelay_aIsfMUNh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GCJqTpbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_a2m3hGAn, 2, m, &cDelay_a2m3hGAn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9PPMwDqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DhQVDVdp, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_b2J7anHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eybfTXrz, HV_BINOP_SUBTRACT, 0, m, &cBinop_eybfTXrz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f4ARP1mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iGZ1KvOi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_iGZ1KvOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wrUPL5M5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_qFRlg7nZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b28jP9ZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_whGtNGtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_whGtNGtH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1nsFx5nZ, 0, m, &cDelay_1nsFx5nZ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LWQT8thL, 0, m, &sTabread_LWQT8thL_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_1nsFx5nZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1nsFx5nZ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LWQT8thL, 0, m, &sTabread_LWQT8thL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1nsFx5nZ, 0, m, &cDelay_1nsFx5nZ_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_LWQT8thL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DkmvqNnL, HV_BINOP_SUBTRACT, 0, m, &cBinop_DkmvqNnL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_WjUWGB29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5U974t19, HV_BINOP_MAX, 0, m, &cBinop_5U974t19_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wrUPL5M5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WjUWGB29, HV_BINOP_MULTIPLY, 0, m, &cBinop_WjUWGB29_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eybfTXrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AfHPQMyT_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LWQT8thL, 0, m, &sTabread_LWQT8thL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_okyfddH6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_63es5iLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DkmvqNnL, HV_BINOP_SUBTRACT, 1, m, &cBinop_DkmvqNnL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1nsFx5nZ, 2, m, &cDelay_1nsFx5nZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b28jP9ZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_63es5iLL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AfHPQMyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_whGtNGtH, 0, m, &cDelay_whGtNGtH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1nsFx5nZ, 0, m, &cDelay_1nsFx5nZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kTd2IHFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_5U974t19, HV_BINOP_MAX, 1, m, &cBinop_5U974t19_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5U974t19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eybfTXrz, HV_BINOP_SUBTRACT, 1, m, &cBinop_eybfTXrz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_okyfddH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_whGtNGtH, 0, m, &cDelay_whGtNGtH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CwiPNdaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_whGtNGtH, 2, m, &cDelay_whGtNGtH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DkmvqNnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CwiPNdaj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F3pUXkHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qFRlg7nZ, 0, m, &cVar_qFRlg7nZ_sendMessage);
  cMsg_f4ARP1mi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_b2J7anHR, 0, m, &cTabhead_b2J7anHR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PpCteJN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_22RQL5Ma, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QCsxydrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VBhB9Bpm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mfbpXeZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FyMxD0mV, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lFBZ0AN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IEh6AtD0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TaiNN5YK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LUr5V32B, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZWSuebiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dFOIhILF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_D37Trl8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_taI8BDWv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mS4x5wDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0uPTYJCF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_6i2C70nA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Y8HtATQk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ty5sKm9R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PvIxfgJX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y8HtATQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6i2C70nA, 1, m, &cVar_6i2C70nA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_BVai2vmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_EhBVpuiv, 0, m, &cVar_EhBVpuiv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_T2QeuIQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_EhBVpuiv, 0, m, &cVar_EhBVpuiv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_uNSVRbnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2QeuIQf, 0, m, &cIf_T2QeuIQf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_G9xelZZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BVai2vmG, 0, m, &cIf_BVai2vmG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_J2BMUtBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0KiQmYEh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_G2Ldt8E9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P5rMZL9b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0KiQmYEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J2BMUtBu, 1, m, &cVar_J2BMUtBu_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_xk82lyPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TEoo99w7, 0, m, &cVar_TEoo99w7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_F0S9j6Og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TEoo99w7, 0, m, &cVar_TEoo99w7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_MUjWEBqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F0S9j6Og, 0, m, &cIf_F0S9j6Og_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bExVQ0z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xk82lyPZ, 0, m, &cIf_xk82lyPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8Oae9Ald_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LyfAJgCB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_arJbMISe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fJLmMfPx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LyfAJgCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Oae9Ald, 1, m, &cVar_8Oae9Ald_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_hoo4U0Yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_BWZ0T9Lv, 0, m, &cVar_BWZ0T9Lv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_YJVqRtQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_BWZ0T9Lv, 0, m, &cVar_BWZ0T9Lv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_XuHGbgAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YJVqRtQQ, 0, m, &cIf_YJVqRtQQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_iKjIJTl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hoo4U0Yq, 0, m, &cIf_hoo4U0Yq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BmF2IkXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WA72jibW, HV_BINOP_DIVIDE, 0, m, &cBinop_WA72jibW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_swIxS9aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FW70wCPc, HV_BINOP_MULTIPLY, 1, m, &cBinop_FW70wCPc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2x8j2v3V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vCobGPtf, 0, m, &cSlice_vCobGPtf_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BOqdh718, 0, m, &cSlice_BOqdh718_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ONGsQm1U_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sSfszesq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_vCobGPtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_wvYnfM35, 0, m, &cVar_wvYnfM35_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wvYnfM35, 0, m, &cVar_wvYnfM35_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_BOqdh718_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_8oc4HfsZ, HV_BINOP_NEQ, 1, m, &cBinop_8oc4HfsZ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wvYnfM35, 1, m, &cVar_wvYnfM35_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_8oc4HfsZ, HV_BINOP_NEQ, 1, m, &cBinop_8oc4HfsZ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wvYnfM35, 1, m, &cVar_wvYnfM35_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wvYnfM35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_FpW6xcRv_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_l5hExdQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dqjwBlsW_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i2ozVbyF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_i2ozVbyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wvYnfM35, 0, m, &cVar_wvYnfM35_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dqjwBlsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8oc4HfsZ, HV_BINOP_NEQ, 1, m, &cBinop_8oc4HfsZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8oc4HfsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l5hExdQx, 1, m, &cIf_l5hExdQx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sSfszesq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l5hExdQx, 0, m, &cIf_l5hExdQx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ONGsQm1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8oc4HfsZ, HV_BINOP_NEQ, 0, m, &cBinop_8oc4HfsZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2yMkZmvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c6KtKCO2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BzswJLmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_xVKkatSd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eDW7d0wC_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f6SzDPRe_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WKT4nTDl_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N06VRtqv_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b5ZfbeEH_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MTW7a2kn_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kz1hlv56_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UiqHL8Xd_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WX6X7F1v_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KCoa1Xf3_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VpgxccTN_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZJLZeKOT_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cHcA3nPD_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_eDW7d0wC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iB4vyXho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_f6SzDPRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Qupf6Fp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WKT4nTDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pjnzl7LP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_N06VRtqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2lBA6o6u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_b5ZfbeEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xqD3CMRR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MTW7a2kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mL31iyeO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kz1hlv56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RZ7PQpDQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_UiqHL8Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pQV19VZK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WX6X7F1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d2MScSXB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KCoa1Xf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bEUg5Ngl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VpgxccTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QeWMNaLe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZJLZeKOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iaGBHMu0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cHcA3nPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jg6RCKCj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WA72jibW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FW70wCPc, HV_BINOP_MULTIPLY, 0, m, &cBinop_FW70wCPc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FW70wCPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2x8j2v3V_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_BzswJLmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BmF2IkXI, 0, m, &cVar_BmF2IkXI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_swIxS9aR, 0, m, &cVar_swIxS9aR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c6KtKCO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WA72jibW, HV_BINOP_DIVIDE, 1, m, &cBinop_WA72jibW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZtkmwZbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BmF2IkXI, 0, m, &cVar_BmF2IkXI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZkcTHEQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_swIxS9aR, 0, m, &cVar_swIxS9aR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iB4vyXho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5Qupf6Fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Pjnzl7LP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2lBA6o6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xqD3CMRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mL31iyeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RZ7PQpDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pQV19VZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_d2MScSXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bEUg5Ngl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QeWMNaLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iaGBHMu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jg6RCKCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkcTHEQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtkmwZbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_RTzZpKrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Z4rVE7W, HV_BINOP_DIVIDE, 0, m, &cBinop_8Z4rVE7W_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_auJ67urk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1eT8FbP, HV_BINOP_MULTIPLY, 1, m, &cBinop_S1eT8FbP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3XLcU4Bq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rfDyMAmi, 0, m, &cSlice_rfDyMAmi_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_E9Gg8hmi, 0, m, &cSlice_E9Gg8hmi_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YfQkUxy2_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z1ELUej2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_rfDyMAmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_XLX15DF5, 0, m, &cVar_XLX15DF5_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_XLX15DF5, 0, m, &cVar_XLX15DF5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_E9Gg8hmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_tdnfQ1vn, HV_BINOP_NEQ, 1, m, &cBinop_tdnfQ1vn_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_XLX15DF5, 1, m, &cVar_XLX15DF5_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_tdnfQ1vn, HV_BINOP_NEQ, 1, m, &cBinop_tdnfQ1vn_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_XLX15DF5, 1, m, &cVar_XLX15DF5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_XLX15DF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_z8C9Q1gP_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tSWQ83Id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oYtERxCr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lK8ar3L0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_oYtERxCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdnfQ1vn, HV_BINOP_NEQ, 1, m, &cBinop_tdnfQ1vn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lK8ar3L0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XLX15DF5, 0, m, &cVar_XLX15DF5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tdnfQ1vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tSWQ83Id, 1, m, &cIf_tSWQ83Id_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z1ELUej2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tSWQ83Id, 0, m, &cIf_tSWQ83Id_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YfQkUxy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdnfQ1vn, HV_BINOP_NEQ, 0, m, &cBinop_tdnfQ1vn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_sPzEKHQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D2mPaK21_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HjZ5mwaW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_IzuPJbnz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6hBsYbze_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FbLRPyWf_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_llllotDv_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9XSWPmXn_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_25DzvW5m_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Aikh1y96_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oRZ50QxT_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1QME7Ea_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b2fEyKN3_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i0pkQduA_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ijc5Mo7l_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TvXVHZZI_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gtENFD8x_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_6hBsYbze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OAMWfVaR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FbLRPyWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HOqZUQj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_llllotDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VGx8nTqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9XSWPmXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yRpl1tD8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_25DzvW5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BI5l6uh2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Aikh1y96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CGdmkZow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_oRZ50QxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wrwbwm3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_c1QME7Ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3WwtAJgU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_b2fEyKN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Flk8x2ic_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_i0pkQduA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DPt8sVj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Ijc5Mo7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SBEsSOwc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_TvXVHZZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eu8JbQSL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_gtENFD8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XssNaDnJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8Z4rVE7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1eT8FbP, HV_BINOP_MULTIPLY, 0, m, &cBinop_S1eT8FbP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S1eT8FbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3XLcU4Bq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_HjZ5mwaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RTzZpKrY, 0, m, &cVar_RTzZpKrY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_auJ67urk, 0, m, &cVar_auJ67urk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_D2mPaK21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Z4rVE7W, HV_BINOP_DIVIDE, 1, m, &cBinop_8Z4rVE7W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kkYk02mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RTzZpKrY, 0, m, &cVar_RTzZpKrY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_T0j83Lrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_auJ67urk, 0, m, &cVar_auJ67urk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OAMWfVaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HOqZUQj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VGx8nTqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yRpl1tD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BI5l6uh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CGdmkZow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wrwbwm3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3WwtAJgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Flk8x2ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DPt8sVj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SBEsSOwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eu8JbQSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XssNaDnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0j83Lrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkYk02mo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_adciQ7bB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NiRu6Iid, HV_BINOP_DIVIDE, 0, m, &cBinop_NiRu6Iid_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_j11lXJy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5jP09w83, HV_BINOP_MULTIPLY, 1, m, &cBinop_5jP09w83_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_6uybjlo5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ISNfMnob, 0, m, &cSlice_ISNfMnob_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EzuJKYnl, 0, m, &cSlice_EzuJKYnl_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1LQvzuz3_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Z57Z092_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ISNfMnob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_NECCct7V, 0, m, &cVar_NECCct7V_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_NECCct7V, 0, m, &cVar_NECCct7V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_EzuJKYnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_t2XOh69n, HV_BINOP_NEQ, 1, m, &cBinop_t2XOh69n_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_NECCct7V, 1, m, &cVar_NECCct7V_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_t2XOh69n, HV_BINOP_NEQ, 1, m, &cBinop_t2XOh69n_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_NECCct7V, 1, m, &cVar_NECCct7V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_NECCct7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_rHOlunHl_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_7GS2bNQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xqd90rED_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bcXbfion_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_Xqd90rED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t2XOh69n, HV_BINOP_NEQ, 1, m, &cBinop_t2XOh69n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bcXbfion_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NECCct7V, 0, m, &cVar_NECCct7V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t2XOh69n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7GS2bNQo, 1, m, &cIf_7GS2bNQo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1LQvzuz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t2XOh69n, HV_BINOP_NEQ, 0, m, &cBinop_t2XOh69n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6Z57Z092_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7GS2bNQo, 0, m, &cIf_7GS2bNQo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1oPkpXdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v1THgPT5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xm4kX76y_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_RQsgyDJK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uXj4fTyC_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6J8cod2t_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PQ9ozkdU_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GY65QodH_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oaExMcKx_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4weTYxoZ_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HYwXFSUE_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BDVXu65h_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NikuD08q_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XM05NvkV_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7L5X53dq_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QBpdSDeC_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eElEX3Fy_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_uXj4fTyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yUcYhmzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6J8cod2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_julLk2IK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PQ9ozkdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TagM0zUO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GY65QodH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OKP8WwxU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_oaExMcKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zgt4s8km_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4weTYxoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MERgZgjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HYwXFSUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UsC4Slc5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BDVXu65h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pYOMy1SS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NikuD08q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DBDfB4Xd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XM05NvkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_geuNkVBx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7L5X53dq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8W92S0Fq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QBpdSDeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QL361lUm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eElEX3Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YTikMYXS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NiRu6Iid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5jP09w83, HV_BINOP_MULTIPLY, 0, m, &cBinop_5jP09w83_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5jP09w83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6uybjlo5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_xm4kX76y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_adciQ7bB, 0, m, &cVar_adciQ7bB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j11lXJy0, 0, m, &cVar_j11lXJy0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v1THgPT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NiRu6Iid, HV_BINOP_DIVIDE, 1, m, &cBinop_NiRu6Iid_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8VAu2nMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_adciQ7bB, 0, m, &cVar_adciQ7bB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MzColM9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j11lXJy0, 0, m, &cVar_j11lXJy0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yUcYhmzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_julLk2IK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TagM0zUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OKP8WwxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Zgt4s8km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MERgZgjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UsC4Slc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pYOMy1SS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DBDfB4Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_geuNkVBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8W92S0Fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QL361lUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YTikMYXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzColM9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8VAu2nMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EPmQ47fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t2IQTM9z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xYjlaajW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YcbDREd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t2IQTM9z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xYjlaajW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4gJZ9QBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t2IQTM9z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xYjlaajW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8sCLLZDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t2IQTM9z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xYjlaajW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oB4WOeYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t2IQTM9z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xYjlaajW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WjCBd3K0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_OY7U2VaK, 0, m, &cVar_OY7U2VaK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NnGqGFdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_AXbO5Sjv, 0, m, &cVar_AXbO5Sjv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2PytRxQw, 0, m, &cVar_2PytRxQw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YdWBrz6Z, 0, m, &cVar_YdWBrz6Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ORbESrXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DdPKkAzf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yZhti01T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DdPKkAzf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_etrHaZcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uSlzpxjw, 0, m, &cVar_uSlzpxjw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w09BoGcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KlP72dZE, 0, m, &cVar_KlP72dZE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dtQM167i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G1Z59iCt, 0, m, &cVar_G1Z59iCt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ek0FlAWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DdPKkAzf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XGlT7bT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DdPKkAzf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XFSquGfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_IVzVfGMY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kSctbacl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_IVzVfGMY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_SYzqc8JV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6UfN2APW, 0, m, &cVar_6UfN2APW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6H2IxvdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PrQu9CWs, 0, m, &cVar_PrQu9CWs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QLcLpOor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_am0fYyba, 0, m, &cVar_am0fYyba_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cymF8dQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_IVzVfGMY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CaZTMnwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_IVzVfGMY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YNhqw2H8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KcTSU0jD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8p2cRWWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KcTSU0jD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_9kmrKEjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e8B7yfFl, 0, m, &cVar_e8B7yfFl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MrvljL3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uBD1aHqX, 0, m, &cVar_uBD1aHqX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gQnzPHkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ime6shVC, 0, m, &cVar_Ime6shVC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4oP5os1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KcTSU0jD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PIs3qdvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KcTSU0jD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_FpW6xcRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G9xelZZI, 0, m, &cVar_G9xelZZI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PvIxfgJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8oWjc2q5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sTlajWmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ty5sKm9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wq9e1WXV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1SfcZhgC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1SfcZhgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uNSVRbnI, 0, m, &cVar_uNSVRbnI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wq9e1WXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2QeuIQf, 1, m, &cIf_T2QeuIQf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8oWjc2q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BVai2vmG, 1, m, &cIf_BVai2vmG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sTlajWmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G9xelZZI, 0, m, &cVar_G9xelZZI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z8C9Q1gP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bExVQ0z9, 0, m, &cVar_bExVQ0z9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P5rMZL9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NE4CqWW3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yJxTT0Kh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G2Ldt8E9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ViIncUj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JzAClMmw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JzAClMmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MUjWEBqk, 0, m, &cVar_MUjWEBqk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4ViIncUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F0S9j6Og, 1, m, &cIf_F0S9j6Og_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NE4CqWW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xk82lyPZ, 1, m, &cIf_xk82lyPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yJxTT0Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bExVQ0z9, 0, m, &cVar_bExVQ0z9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rHOlunHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iKjIJTl7, 0, m, &cVar_iKjIJTl7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fJLmMfPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sPiRnbfo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hgsLvu5m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_arJbMISe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xEMsydBm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YRF5zNpk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YRF5zNpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XuHGbgAp, 0, m, &cVar_XuHGbgAp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xEMsydBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YJVqRtQQ, 1, m, &cIf_YJVqRtQQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hgsLvu5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iKjIJTl7, 0, m, &cVar_iKjIJTl7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sPiRnbfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hoo4U0Yq, 1, m, &cIf_hoo4U0Yq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5yCl8fDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AXbO5Sjv, 0, m, &cVar_AXbO5Sjv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jThceXdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2PytRxQw, 0, m, &cVar_2PytRxQw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wgS0X0Li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YdWBrz6Z, 0, m, &cVar_YdWBrz6Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RZYknDTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5g9LEraM, 0, m, &cVar_5g9LEraM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ultMTieE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QHYt7uXP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kl9iALGd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lm4GTJbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7aYqXK2V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_trW4PTkW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ThGChaRB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pKjAgZQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WtsWSQAB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cJACEb9q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DAXq6YLN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8qkhXCOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SlZ1ehiS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AKyjT22I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gPs1ImaL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_91hXEloU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vf9DtBpz_sendMessage(_c, 0, m);
  cMsg_Rue6gK9g_sendMessage(_c, 0, m);
  cMsg_GE8e1FmV_sendMessage(_c, 0, m);
  cMsg_RElnjfAk_sendMessage(_c, 0, m);
  cMsg_3C4WFv9q_sendMessage(_c, 0, m);
  cMsg_WWvIfeuT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7ECkqL6v, 0, m, &cVar_7ECkqL6v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5g9LEraM, 0, m, &cVar_5g9LEraM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_e0tsPdz0, 0, m, &cVar_e0tsPdz0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nndcYOA8, 0, m, &cVar_nndcYOA8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KZLXJnN7, 0, m, &cVar_KZLXJnN7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Lkt0X7Xo, 0, m, &cVar_Lkt0X7Xo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_r6jI6S3k, 0, m, &cVar_r6jI6S3k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BwBNfBwq, 0, m, &cVar_BwBNfBwq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JJqnYndt, 0, m, &cVar_JJqnYndt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_U3CUCqks, 0, m, &cVar_U3CUCqks_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0DrZaClI, 0, m, &cVar_0DrZaClI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_59Eqb6nc, 0, m, &cVar_59Eqb6nc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RwL9C1j0, 0, m, &cVar_RwL9C1j0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6UOPJPMG, 0, m, &cVar_6UOPJPMG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OQQtW4ZD, 0, m, &cVar_OQQtW4ZD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c94ZfsFZ, 0, m, &cVar_c94ZfsFZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZCuWE7OH, 0, m, &cVar_ZCuWE7OH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ngyeh0ac, 0, m, &cVar_Ngyeh0ac_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ghHXe96N, 0, m, &cVar_ghHXe96N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9qUNI9Ma, 0, m, &cVar_9qUNI9Ma_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S7udzymx, 0, m, &cVar_S7udzymx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xug79lXV, 0, m, &cVar_xug79lXV_sendMessage);
  cMsg_bWozNsz8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CGJF1LFS, 0, m, &cVar_CGJF1LFS_sendMessage);
  cMsg_oRlneRSG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bkhmXzJC, 0, m, &cVar_bkhmXzJC_sendMessage);
  cMsg_SiqraxlE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JJS60vaC, 0, m, &cVar_JJS60vaC_sendMessage);
  cMsg_qA3fA0CO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QYAZVMtJ, 0, m, &cVar_QYAZVMtJ_sendMessage);
  cMsg_IETo5XLq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fllZJJZW, 0, m, &cVar_fllZJJZW_sendMessage);
  cMsg_bpR3ZwoQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bIc6VeQS, 0, m, &cVar_bIc6VeQS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aufUVtsL, 0, m, &cVar_aufUVtsL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i4TRNVX2, 0, m, &cVar_i4TRNVX2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X7f4kiAh, 0, m, &cVar_X7f4kiAh_sendMessage);
  cMsg_fP5fzTwb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_clVkHWx3, 0, m, &cVar_clVkHWx3_sendMessage);
  cMsg_2V9JUCwk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_K8IajlmD, 0, m, &cVar_K8IajlmD_sendMessage);
  cMsg_IvCRWIxW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vS3rOOfN, 0, m, &cVar_vS3rOOfN_sendMessage);
  cMsg_srtiCEDB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_971ISvvg, 0, m, &cVar_971ISvvg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SxRafSm9, 0, m, &cVar_SxRafSm9_sendMessage);
  cMsg_bJ3aMUFL_sendMessage(_c, 0, m);
  cMsg_jPU8J6Pt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Y5N5TASe, 0, m, &cVar_Y5N5TASe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kaDhFWoC, 0, m, &cVar_kaDhFWoC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pcuyoBHd, 0, m, &cVar_pcuyoBHd_sendMessage);
  cMsg_xDnof6oU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7OwCZxc4, 0, m, &cVar_7OwCZxc4_sendMessage);
  cMsg_tuQQBWAX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_29y5FrVr, 0, m, &cVar_29y5FrVr_sendMessage);
  cMsg_YPLm1dkH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jHr3jXLF, 0, m, &cVar_jHr3jXLF_sendMessage);
  cMsg_tvTOSdNC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CXvek7WL, 0, m, &cVar_CXvek7WL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KQ35b6SB, 0, m, &cVar_KQ35b6SB_sendMessage);
  cMsg_1SVrano7_sendMessage(_c, 0, m);
  cMsg_nKUGGNM4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_X13MR2Rt, 0, m, &cVar_X13MR2Rt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jAWVpFLO, 0, m, &cVar_jAWVpFLO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QFuhcyby, 0, m, &cVar_QFuhcyby_sendMessage);
  cMsg_EblcbFIZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MqAiXUAP, 0, m, &cVar_MqAiXUAP_sendMessage);
  cMsg_VfBbF17a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BDs7NsPI, 0, m, &cVar_BDs7NsPI_sendMessage);
  cMsg_MngXBp1B_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PufZaAAw, 0, m, &cVar_PufZaAAw_sendMessage);
  cMsg_hGYFvSVZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uq11AUSS, 0, m, &cVar_uq11AUSS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3VEIbLft, 0, m, &cVar_3VEIbLft_sendMessage);
  cMsg_LmYpHARm_sendMessage(_c, 0, m);
  cMsg_1E25FUY8_sendMessage(_c, 0, m);
  cMsg_NnGqGFdi_sendMessage(_c, 0, m);
  cMsg_WjCBd3K0_sendMessage(_c, 0, m);
  cMsg_ouo98YJt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nDt8bQRO, 0, m, &cVar_nDt8bQRO_sendMessage);
  cMsg_Uucd5rak_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mP322oaN, 0, m, &cTabhead_mP322oaN_sendMessage);
  cMsg_lomVFOgS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8sOvARzH, 0, m, &cVar_8sOvARzH_sendMessage);
  cMsg_jRdoevrk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_M1GclX0t, 0, m, &cTabhead_M1GclX0t_sendMessage);
  cMsg_GSFEtPRQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8R1r3GfX, 0, m, &cVar_8R1r3GfX_sendMessage);
  cMsg_UrPk7Ikx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nTffNHYv, 0, m, &cTabhead_nTffNHYv_sendMessage);
  cMsg_zr3c5naw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MyF71C90, 0, m, &cVar_MyF71C90_sendMessage);
  cMsg_ziiH9h8y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Ghe7FRaA, 0, m, &cTabhead_Ghe7FRaA_sendMessage);
  cMsg_FjjGVcuY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YcXXOJls, 0, m, &cVar_YcXXOJls_sendMessage);
  cMsg_zHdAk2q1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_GvFFjUM4, 0, m, &cTabhead_GvFFjUM4_sendMessage);
  cMsg_kTd2IHFy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qFRlg7nZ, 0, m, &cVar_qFRlg7nZ_sendMessage);
  cMsg_f4ARP1mi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_b2J7anHR, 0, m, &cTabhead_b2J7anHR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uVvFYnz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0J7q58Ru, HV_BINOP_MULTIPLY, 0, m, &cBinop_0J7q58Ru_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uBv0Jhs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_x1OJoXzx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NnhKPyck_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5NR4l5kK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_8crXyorU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4tNRFDSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hJxNltKr_sendMessage);
  cMsg_XLw2SBSe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_VzCIyYuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KdH993CY, HV_BINOP_MULTIPLY, 0, m, &cBinop_KdH993CY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_h8ULmtvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_cFV3Qaul_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IPq9UB7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q3wPmr8Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_q3wPmr8Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rH5KhOhd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ao4oJ0j8_sendMessage);
  cMsg_ZKfDDCZx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_2aJUMg2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9WyMHci, HV_BINOP_MULTIPLY, 0, m, &cBinop_L9WyMHci_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HZ4TsLTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XmpgrtlA_sendMessage(_c, 0, m);
  cMsg_LsiIBKYN_sendMessage(_c, 0, m);
  cMsg_B2HU7HQN_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HLnds4WB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GNyMy371_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IfViw6E7_sendMessage);
  cMsg_pRJ1AnHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_Got0Xith_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KZLXJnN7, 0, m, &cVar_KZLXJnN7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_axOAg1yy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sqO7Tkq7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DpUs0J0s_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ABQH6Iz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BBNKACd9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_quJWkzXY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1N3t94x0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_13WWtu6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XrgVegmr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DP4mpUP8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OAVNe7Nk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UaNNQi3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9rXGCOKh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qFQkCTSj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6mmbffN4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KhFyb1nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzeHlptN, HV_BINOP_MULTIPLY, 0, m, &cBinop_MzeHlptN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vdYXKS9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xhEjLgBD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NaHNCsbS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MG6xx9RQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_QP6onF41_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_02qdIdsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qVrpSz69_sendMessage);
  cMsg_IgkBedCk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_8B3hjd2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_75zaU9nt, HV_BINOP_MULTIPLY, 0, m, &cBinop_75zaU9nt_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jR89ybvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_F9LYoj4Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_DFBQ1Y86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lj73q1A1, HV_BINOP_MULTIPLY, 1, m, &cBinop_lj73q1A1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YWIDRa2F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_piX8sBMo_sendMessage);
  cMsg_4TC0f3Yt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_wBqOnhFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_enfZRpkA, HV_BINOP_MULTIPLY, 0, m, &cBinop_enfZRpkA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zULV5ztl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_90ZRnGe0_sendMessage(_c, 0, m);
  cMsg_J9QK2jsp_sendMessage(_c, 0, m);
  cMsg_20Qy5Nvm_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_lpObJf1Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_owScGmPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_X2cGfkJL_sendMessage);
  cMsg_kTqjcbwg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_ov4mLnwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OY7U2VaK, 0, m, &cVar_OY7U2VaK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1B1Gbih0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_etrHaZcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_plToDt7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_w09BoGcZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IC2TnVhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_dtQM167i_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vZ7cjAHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SYzqc8JV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RcHHnESz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6H2IxvdT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IVOJq5So_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9kmrKEjb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2l0BSAkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_MrvljL3r_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1cXn7H0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gQnzPHkr_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RJK0hIlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QLcLpOor_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1syAALUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dFERwm9d, HV_BINOP_MULTIPLY, 1, m, &cBinop_dFERwm9d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6NpqY6tY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qLZrWkYL, HV_BINOP_MULTIPLY, 1, m, &cBinop_qLZrWkYL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gBplESYc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RuSxj0LV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_e5CwZl64, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eqXmRtHi, m);
}

void Heavy_WSTD_DL3Y::cReceive_R7RAs2Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JzqGmLcb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Rl2FVR1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vmLWMwN9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NBIhRw3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uRnFoNJd, HV_BINOP_MULTIPLY, 1, m, &cBinop_uRnFoNJd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7WmpIDn1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pZnVhTXy, HV_BINOP_MULTIPLY, 1, m, &cBinop_pZnVhTXy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g9A6MLrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5LcZgoEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ygsu9OUN, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qT50L60W, m);
}

void Heavy_WSTD_DL3Y::cReceive_8A9rf8Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zbCYO5pD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xNlGnxRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GS5TXSpi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_DAsxlMQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Lndy6LB, HV_BINOP_MULTIPLY, 1, m, &cBinop_0Lndy6LB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h7LZxvl7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WjUWGB29, HV_BINOP_MULTIPLY, 1, m, &cBinop_WjUWGB29_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F3pUXkHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bOtZ65lP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xywW3tYe, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7rpfwOsr, m);
}

void Heavy_WSTD_DL3Y::cReceive_Bf1i9WFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LsuIjASs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VynHoDs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_e9cTntek_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mIvg7UN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uNSVRbnI, 0, m, &cVar_uNSVRbnI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jVfIidcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6i2C70nA, 0, m, &cVar_6i2C70nA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5z397qdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J2BMUtBu, 0, m, &cVar_J2BMUtBu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SfhctQtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MUjWEBqk, 0, m, &cVar_MUjWEBqk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GKg9dXJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XuHGbgAp, 0, m, &cVar_XuHGbgAp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cUBaNGsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Oae9Ald, 0, m, &cVar_8Oae9Ald_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MUKQ7iY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2yMkZmvh, 0, m, &cVar_2yMkZmvh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sPzEKHQg, 0, m, &cVar_sPzEKHQg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1oPkpXdG, 0, m, &cVar_1oPkpXdG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RVeaHMk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IzuPJbnz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_Sayeqbw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xVKkatSd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_yn9OZvuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RQsgyDJK_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_i17lkaD1, VOf(Bf0));
    __hv_line_f(&sLine_yBNMQttX, VOf(Bf1));
    __hv_line_f(&sLine_z8o1tWO5, VOf(Bf2));
    __hv_line_f(&sLine_GylzzhHX, VOf(Bf3));
    __hv_line_f(&sLine_wPCvNx7Z, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_y3y0JTdX, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_0YZk9llM, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_1e8gzSNb, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_LzkCL5yO, VOf(Bf1));
    __hv_line_f(&sLine_4ggMVONL, VOf(Bf0));
    __hv_line_f(&sLine_SdJE9qek, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_LNcCUCDH, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_uL5QktVP, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_PT12fJqN, VOf(Bf5));
    __hv_line_f(&sLine_Vwas8GJG, VOf(Bf1));
    __hv_line_f(&sLine_ARJ4JUFg, VOf(Bf2));
    __hv_line_f(&sLine_Dw8fMamX, VOf(Bf4));
    __hv_line_f(&sLine_XZUHoKAa, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_ucg4ZGhM, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_trkcUVdP, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_X6SkB0qt, VOf(Bf6));
    __hv_line_f(&sLine_hlEVM56W, VOf(Bf2));
    __hv_line_f(&sLine_dOlal1uc, VOf(Bf1));
    __hv_line_f(&sLine_IV8gRcXT, VOf(Bf5));
    __hv_line_f(&sLine_KlMu4Xnp, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_G5w08bZA, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_0PiTYQeo, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_bMiLZSfL, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_noGJ8Bs5, VOf(Bf2));
    __hv_line_f(&sLine_y5hvFAve, VOf(Bf6));
    __hv_line_f(&sLine_Z5XQCOKO, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_jOQwLY2z, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_2Pkg2wrO, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_LiQwFgQD, VOf(Bf8));
    __hv_line_f(&sLine_42cvQX6S, VOf(Bf2));
    __hv_line_f(&sLine_gmb4aNSK, VOf(Bf1));
    __hv_line_f(&sLine_Mz264Jhf, VOf(Bf7));
    __hv_line_f(&sLine_lMhigCLd, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_CaCHW6nc, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_JmQiuHKg, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_PrtZ0oGD, VOf(Bf9));
    __hv_tabread_f(&sTabread_qtYBFBNz, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_6vvtxlCT, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_5AzsYKWF, VOf(Bf9));
    __hv_tabread_f(&sTabread_PuHz1jA1, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_2tYUzbyE, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_3VUtJlMC, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_QBN7SZs6, VOf(Bf3));
    __hv_rpole_f(&sRPole_A01frPFX, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_KW3cJ0OB, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_GPhYARTr, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_yRd2oXvf, VIf(Bf3));
    __hv_varread_f(&sVarf_UaM1xjog, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_dolqjpk0, VOf(Bf5));
    __hv_rpole_f(&sRPole_a82uExel, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_RglmwNh0, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_WQP5sq2L, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_LRerAZqE, VIf(Bf5));
    __hv_varread_f(&sVarf_e5CwZl64, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_9AUnoLtp, VOf(Bf1));
    __hv_varread_f(&sVarf_eqXmRtHi, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_Z7ex0L7N, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_TouNETNv, VOf(Bf1));
    __hv_varread_f(&sVarf_qEpVf039, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Ig0q2iWb, VOf(Bf1));
    __hv_rpole_f(&sRPole_RNgupQcF, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_YG5JW3qM, VIf(Bf8), &sEnv_YG5JW3qM_sendMessage);
    __hv_varread_f(&sVarf_iHuAaSxG, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_DUg41zIx, VOf(Bf1));
    __hv_rpole_f(&sRPole_voSv0ICF, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_3VUtJlMC, VIf(Bf1));
    __hv_line_f(&sLine_xccofcGN, VOf(Bf1));
    __hv_line_f(&sLine_jRTTgQzQ, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_QnCJP76l, VOf(Bf1));
    __hv_varread_f(&sVarf_6HlDSI4u, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_SkutqVR5, VOf(Bf1));
    __hv_rpole_f(&sRPole_JzDkAFjz, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_SPufftx8, VIf(Bf8), &sEnv_SPufftx8_sendMessage);
    __hv_varread_f(&sVarf_Eq1L04zV, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_CEI8aHd2, VOf(Bf1));
    __hv_rpole_f(&sRPole_c6jm5OXu, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_UaM1xjog, VIf(Bf1));
    __hv_varwrite_f(&sVarf_eKzojl3k, VIf(Bf2));
    __hv_varread_f(&sVarf_J2BGifcF, VOf(Bf2));
    __hv_varread_f(&sVarf_TtZXnZxH, VOf(Bf1));
    __hv_line_f(&sLine_BDpGbARy, VOf(Bf8));
    __hv_tabread_f(&sTabread_bDtyNDwy, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_s3wZsadc, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_SvVixzbw, VOf(Bf8));
    __hv_tabread_f(&sTabread_g5HOcDJY, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_GeFHToa6, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_aUF6JAUX, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ehM1n0Tj, VOf(Bf2));
    __hv_rpole_f(&sRPole_KLxU3SqZ, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Yys5gPNR, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_VME72CB5, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_oHkOsNvn, VIf(Bf2));
    __hv_varread_f(&sVarf_2wHf2d71, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_RIgLIP4l, VOf(Bf1));
    __hv_rpole_f(&sRPole_zNrkbuwV, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_gTL3YliV, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_w3oxMSC7, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_PdEEiYqK, VIf(Bf1));
    __hv_varread_f(&sVarf_Ygsu9OUN, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_7hDTQupF, VOf(Bf3));
    __hv_varread_f(&sVarf_qT50L60W, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_tH7vOrtF, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_VYEmcgEk, VOf(Bf3));
    __hv_varread_f(&sVarf_D3kKcMEt, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_OQkyyzXS, VOf(Bf3));
    __hv_rpole_f(&sRPole_bhfHs6AF, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_FqrPj7Xq, VIf(Bf9), &sEnv_FqrPj7Xq_sendMessage);
    __hv_varread_f(&sVarf_C1IBS9qV, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Edfj2HRe, VOf(Bf3));
    __hv_rpole_f(&sRPole_sFrhiaDY, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_aUF6JAUX, VIf(Bf3));
    __hv_line_f(&sLine_i5SdvvvW, VOf(Bf3));
    __hv_line_f(&sLine_cZfhy0zA, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_c4bbhSlr, VOf(Bf3));
    __hv_varread_f(&sVarf_aMD6959m, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_p9ZiHA4h, VOf(Bf3));
    __hv_rpole_f(&sRPole_yuzC8fza, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_IH28Stkf, VIf(Bf9), &sEnv_IH28Stkf_sendMessage);
    __hv_varread_f(&sVarf_xy0pJ8Km, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_8i7I6oih, VOf(Bf3));
    __hv_rpole_f(&sRPole_151Ex3AQ, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_2wHf2d71, VIf(Bf3));
    __hv_varwrite_f(&sVarf_r3tDfpdC, VIf(Bf5));
    __hv_varread_f(&sVarf_RN5jPWxZ, VOf(Bf5));
    __hv_varread_f(&sVarf_AEmVFssH, VOf(Bf3));
    __hv_line_f(&sLine_VBhB9Bpm, VOf(Bf9));
    __hv_tabread_f(&sTabread_B8XWFxj1, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_22RQL5Ma, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_FyMxD0mV, VOf(Bf9));
    __hv_tabread_f(&sTabread_LWQT8thL, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_IEh6AtD0, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_oIVygBWk, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_55TTeHmd, VOf(Bf5));
    __hv_rpole_f(&sRPole_gtYUhcWe, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_YKOxmpuO, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_H9kF90De, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_aYXx9EZk, VIf(Bf5));
    __hv_varread_f(&sVarf_o10vBUDk, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_e3FpJZQ8, VOf(Bf3));
    __hv_rpole_f(&sRPole_NpCIOON9, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_z5LyoNtB, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_H7IJF0p8, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_DhQVDVdp, VIf(Bf3));
    __hv_varread_f(&sVarf_xywW3tYe, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_dFOIhILF, VOf(Bf2));
    __hv_varread_f(&sVarf_7rpfwOsr, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_LUr5V32B, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_X37SBS4D, VOf(Bf2));
    __hv_varread_f(&sVarf_CKBnMWEE, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_bnEfwBc5, VOf(Bf2));
    __hv_rpole_f(&sRPole_uM50NfZA, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_yWpweweR, VIf(Bf8), &sEnv_yWpweweR_sendMessage);
    __hv_varread_f(&sVarf_iRxYRSYl, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_b7cQaKsN, VOf(Bf2));
    __hv_rpole_f(&sRPole_H0YxJRMR, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_oIVygBWk, VIf(Bf2));
    __hv_line_f(&sLine_0uPTYJCF, VOf(Bf2));
    __hv_line_f(&sLine_taI8BDWv, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_CCiOsY7B, VOf(Bf2));
    __hv_varread_f(&sVarf_1BmDoouT, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_AlWM4wZy, VOf(Bf2));
    __hv_rpole_f(&sRPole_t1BQ1wFm, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_4snyFlJo, VIf(Bf8), &sEnv_4snyFlJo_sendMessage);
    __hv_varread_f(&sVarf_j0tWJvbN, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_5rkpezbR, VOf(Bf2));
    __hv_rpole_f(&sRPole_JzIvygaC, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_o10vBUDk, VIf(Bf2));
    __hv_varwrite_f(&sVarf_7qMpAmUj, VIf(Bf1));
    __hv_varwrite_f(&sVarf_FlKTU6zS, VIf(Bf10));
    __hv_varwrite_f(&sVarf_346UYbiu, VIf(Bf11));
    __hv_varwrite_f(&sVarf_Nl6aQvIT, VIf(Bf12));
    __hv_varwrite_f(&sVarf_J2BGifcF, VIf(Bf0));
    __hv_varwrite_f(&sVarf_TtZXnZxH, VIf(Bf6));
    __hv_varwrite_f(&sVarf_RN5jPWxZ, VIf(Bf4));
    __hv_varwrite_f(&sVarf_AEmVFssH, VIf(Bf7));
    __hv_varread_f(&sVarf_eKzojl3k, VOf(Bf7));
    __hv_varread_f(&sVarf_r3tDfpdC, VOf(Bf4));
    __hv_varread_f(&sVarf_7qMpAmUj, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_FlKTU6zS, VOf(Bf6));
    __hv_varread_f(&sVarf_346UYbiu, VOf(Bf7));
    __hv_varread_f(&sVarf_Nl6aQvIT, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
